# CheckSystem

Various system related checks, such as CPU load, process state, service state memory usage and PDH counters.



**List of commands:**

A list of all available queries (check commands)

| Command                                 | Description                                                                   |
|-----------------------------------------|-------------------------------------------------------------------------------|
| [check_cpu](#check_cpu)                 | Check that the load of the CPU(s) are within bounds.                          |
| [check_memory](#check_memory)           | Check free/used memory on the system.                                         |
| [check_network](#check_network)         | Check network interface status.                                               |
| [check_os_version](#check_os_version)   | Check the version of the underlaying OS.                                      |
| [check_pagefile](#check_pagefile)       | Check the size of the system pagefile(s).                                     |
| [check_pdh](#check_pdh)                 | Check the value of a performance (PDH) counter on the local or remote system. |
| [check_process](#check_process)         | Check state/metrics of one or more of the processes running on the computer.  |
| [check_service](#check_service)         | Check the state of one or more of the computer services.                      |
| [check_uptime](#check_uptime)           | Check time since last server re-boot.                                         |
| [checkcounter](#checkcounter)           | Legacy version of check_pdh                                                   |
| [checkcpu](#checkcpu)                   | Legacy version of check_cpu                                                   |
| [checkmem](#checkmem)                   | Legacy version of check_mem                                                   |
| [checkprocstate](#checkprocstate)       | Legacy version of check_process                                               |
| [checkservicestate](#checkservicestate) | Legacy version of check_service                                               |
| [checkuptime](#checkuptime)             | Legacy version of check_uptime                                                |


**List of command aliases:**

A list of all short hand aliases for queries (check commands)


| Command       | Description                   |
|---------------|-------------------------------|
| check_counter | Alias for: :query:`check_pdh` |


**Configuration Keys:**



    
    
    
    
    
    
| Path / Section                                        | Key                                                                      | Description              |
|-------------------------------------------------------|--------------------------------------------------------------------------|--------------------------|
| [/settings/system/windows](#/settings/system/windows) | [default buffer length](#/settings/system/windows_default buffer length) | Default buffer time      |
| [/settings/system/windows](#/settings/system/windows) | [disable](#/settings/system/windows_disable)                             | Disable automatic checks |
| [/settings/system/windows](#/settings/system/windows) | [subsystem](#/settings/system/windows_subsystem)                         | PDH subsystem            |


| Path / Section                                                                            | Description              |
|-------------------------------------------------------------------------------------------|--------------------------|
| [/settings/system/windows/counters](#/settings/system/windows/counters)                   | PDH Counters             |
| [/settings/system/windows/real-time/checks](#/settings/system/windows/real-time/checks)   | Legacy generic filters   |
| [/settings/system/windows/real-time/cpu](#/settings/system/windows/real-time/cpu)         | Realtime cpu filters     |
| [/settings/system/windows/real-time/memory](#/settings/system/windows/real-time/memory)   | Realtime memory filters  |
| [/settings/system/windows/real-time/process](#/settings/system/windows/real-time/process) | Realtime process filters |



## Queries

A quick reference for all available queries (check commands) in the CheckSystem module.

### check_cpu

Check that the load of the CPU(s) are within bounds.

The check_cpu command is a query based command which means it has a filter where you can use a filter expression with filter keywords to define which rows are relevant to the check.
The filter is written using the filter query language and in it you can use various filter keywords to define the filtering logic.
The filter keywords can also be used to create the bound expressions for the warning and critical which defines when a check returns warning or critical.

* [Samples](#check_cpu_samples)

* [Command-line Arguments](#check_cpu_options)
* [Filter keywords](#check_cpu_filter_keys)


<a name="check_cpu_samples"/>
#### Sample Commands

_To edit these sample please edit [this page](https://github.com/mickem/nscp-docs/blob/master/samples/CheckSystem_check_cpu_samples.md)_

**Default check:**

```
check_cpu
CPU Load ok
'total 5m load'=0%;80;90 'total 1m load'=0%;80;90 'total 5s load'=7%;80;90
```

Checking **all cores** by adding filter=none (disabling the filter):

```
check_cpu filter=none "warn=load > 80" "crit=load > 90"
CPU Load ok
'core 0 5m kernel'=1%;10;0 'core 0 5m load'=3%;80;90 'core 1 5m kernel'=0%;10;0 'core 1 5m load'=0%;80;90 ...  'core 7 5s load'=15%;80;90 'total 5s kernel'=3%;10;0 'total 5s load'=7%;80;90
```

Adding kernel times to the check::

```
check_cpu filter=none "warn=kernel > 10 or load > 80" "crit=load > 90" "top-syntax=${list}"
core 0 > 3, core 1 > 0, core 2 > 0, core  ... , core 7 > 15, total > 7
'core 0 5m kernel'=1%;10;0 'core 0 5m load'=3%;80;90 'core 1 5m kernel'=0%;10;0 'core 1 5m load'=0%;80;90 ...  'core 7 5s load'=15%;80;90 'total 5s kernel'=3%;10;0 'total 5s load'=7%;80;90
```

Default check **via NRPE**::

```
check_nscp --host 192.168.56.103 --command check_cpu
CPU Load ok|'total 5m'=16%;80;90 'total 1m'=13%;80;90 'total 5s'=13%;80;90
```



<a name="check_cpu_warn"/>

<a name="check_cpu_crit"/>

<a name="check_cpu_debug"/>

<a name="check_cpu_show-all"/>

<a name="check_cpu_escape-html"/>

<a name="check_cpu_help"/>

<a name="check_cpu_help-pb"/>

<a name="check_cpu_show-default"/>

<a name="check_cpu_help-short"/>

<a name="check_cpu_time"/>

<a name="check_cpu_options"/>
#### Command-line Arguments


| Option                                    | Default Value              | Description                                                                                                      |
|-------------------------------------------|----------------------------|------------------------------------------------------------------------------------------------------------------|
| [filter](#check_cpu_filter)               | core = 'total'             | Filter which marks interesting items.                                                                            |
| [warning](#check_cpu_warning)             | load > 80                  | Filter which marks items which generates a warning state.                                                        |
| warn                                      |                            | Short alias for warning                                                                                          |
| [critical](#check_cpu_critical)           | load > 90                  | Filter which marks items which generates a critical state.                                                       |
| crit                                      |                            | Short alias for critical.                                                                                        |
| [ok](#check_cpu_ok)                       |                            | Filter which marks items which generates an ok state.                                                            |
| debug                                     | N/A                        | Show debugging information in the log                                                                            |
| show-all                                  | N/A                        | Show details for all matches regardless of status (normally details are only showed for warnings and criticals). |
| [empty-state](#check_cpu_empty-state)     | ignored                    | Return status to use when nothing matched filter.                                                                |
| [perf-config](#check_cpu_perf-config)     |                            | Performance data generation configuration                                                                        |
| escape-html                               | N/A                        | Escape any < and > characters to prevent HTML encoding                                                           |
| help                                      | N/A                        | Show help screen (this screen)                                                                                   |
| help-pb                                   | N/A                        | Show help screen as a protocol buffer payload                                                                    |
| show-default                              | N/A                        | Show default values for a given command                                                                          |
| help-short                                | N/A                        | Show help screen (short format).                                                                                 |
| [top-syntax](#check_cpu_top-syntax)       | ${status}: ${problem_list} | Top level syntax.                                                                                                |
| [ok-syntax](#check_cpu_ok-syntax)         | %(status): CPU load is ok. | ok syntax.                                                                                                       |
| [empty-syntax](#check_cpu_empty-syntax)   |                            | Empty syntax.                                                                                                    |
| [detail-syntax](#check_cpu_detail-syntax) | ${time}: ${load}%          | Detail level syntax.                                                                                             |
| [perf-syntax](#check_cpu_perf-syntax)     | ${core} ${time}            | Performance alias syntax.                                                                                        |
| time                                      |                            | The time to check                                                                                                |



<a name="check_cpu_filter"/>
**filter:**

Filter which marks interesting items.
Interesting items are items which will be included in the check.
They do not denote warning or critical state instead it defines which items are relevant and you can remove unwanted items.


*Deafult Value:* | `core = 'total'`



<a name="check_cpu_warning"/>
**warning:**

Filter which marks items which generates a warning state.
If anything matches this filter the return status will be escalated to warning.



*Deafult Value:* | `load > 80`



<a name="check_cpu_critical"/>
**critical:**

Filter which marks items which generates a critical state.
If anything matches this filter the return status will be escalated to critical.



*Deafult Value:* | `load > 90`



<a name="check_cpu_ok"/>
**ok:**

Filter which marks items which generates an ok state.
If anything matches this any previous state for this item will be reset to ok.






<a name="check_cpu_empty-state"/>
**empty-state:**

Return status to use when nothing matched filter.
If no filter is specified this will never happen unless the file is empty.


*Deafult Value:* | `ignored`



<a name="check_cpu_perf-config"/>
**perf-config:**

Performance data generation configuration
TODO: obj ( key: value; key: value) obj (key:valuer;key:value)





<a name="check_cpu_top-syntax"/>
**top-syntax:**

Top level syntax.
Used to format the message to return can include text as well as special keywords which will include information from the checks.
To add a keyword to the message you can use two syntaxes either ${keyword} or %(keyword) (there is no difference between them apart from ${} can be difficult to excpae on linux).


*Deafult Value:* | `${status}: ${problem_list}`



<a name="check_cpu_ok-syntax"/>
**ok-syntax:**

ok syntax.
DEPRECATED! This is the syntax for when an ok result is returned.
This value will not be used if your syntax contains %(list) or %(count).


*Deafult Value:* | `%(status): CPU load is ok.`



<a name="check_cpu_empty-syntax"/>
**empty-syntax:**

Empty syntax.
DEPRECATED! This is the syntax for when nothing matches the filter.





<a name="check_cpu_detail-syntax"/>
**detail-syntax:**

Detail level syntax.
Used to format each resulting item in the message.
%(list) will be replaced with all the items formated by this syntax string in the top-syntax.
To add a keyword to the message you can use two syntaxes either ${keyword} or %(keyword) (there is no difference between them apart from ${} can be difficult to excpae on linux).


*Deafult Value:* | `${time}: ${load}%`



<a name="check_cpu_perf-syntax"/>
**perf-syntax:**

Performance alias syntax.
This is the syntax for the base names of the performance data.


*Deafult Value:* | `${core} ${time}`




<a name="check_cpu_filter_keys"/>
#### Filter keywords


| Option                                    | Description                                                                                                  |
|-------------------------------------------|--------------------------------------------------------------------------------------------------------------|
| [core](#check_cpu_core)                   | The core to check (total or core ##)                                                                         |
| [core_id](#check_cpu_core_id)             | The core to check (total or core_##)                                                                         |
| [count](#check_cpu_count)                 | Number of items matching the filter. Common option for all checks.                                           |
| [crit_count](#check_cpu_crit_count)       | Number of items matched the critical criteria. Common option for all checks.                                 |
| [crit_list](#check_cpu_crit_list)         | A list of all items which matched the critical criteria. Common option for all checks.                       |
| [detail_list](#check_cpu_detail_list)     | A special list with critical, then warning and finally ok. Common option for all checks.                     |
| [idle](#check_cpu_idle)                   | The current idle load for a given core                                                                       |
| [kernel](#check_cpu_kernel)               | The current kernel load for a given core                                                                     |
| [list](#check_cpu_list)                   | A list of all items which matched the filter. Common option for all checks.                                  |
| [load](#check_cpu_load)                   | The current load for a given core                                                                            |
| [ok_count](#check_cpu_ok_count)           | Number of items matched the ok criteria. Common option for all checks.                                       |
| [ok_list](#check_cpu_ok_list)             | A list of all items which matched the ok criteria. Common option for all checks.                             |
| [problem_count](#check_cpu_problem_count) | Number of items matched either warning or critical criteria. Common option for all checks.                   |
| [problem_list](#check_cpu_problem_list)   | A list of all items which matched either the critical or the warning criteria. Common option for all checks. |
| [status](#check_cpu_status)               | The returned status (OK/WARN/CRIT/UNKNOWN). Common option for all checks.                                    |
| [time](#check_cpu_time)                   | The time frame to check                                                                                      |
| [total](#check_cpu_total)                 | Total number of items. Common option for all checks.                                                         |
| [warn_count](#check_cpu_warn_count)       | Number of items matched the warning criteria. Common option for all checks.                                  |
| [warn_list](#check_cpu_warn_list)         | A list of all items which matched the warning criteria. Common option for all checks.                        |


### check_memory

Check free/used memory on the system.

* [Samples](#check_memory_samples)

* [Command-line Arguments](#check_memory_options)
* [Filter keywords](#check_memory_filter_keys)


<a name="check_memory_samples"/>
#### Sample Commands

_To edit these sample please edit [this page](https://github.com/mickem/nscp-docs/blob/master/samples/CheckSystem_check_memory_samples.md)_

**Default check:**

```
check_memory
OK memory within bounds.
'page used'=8G;19;21 'page used %'=33%;79;89 'physical used'=7G;9;10 'physical used %'=65%;79;89
```

Using --show-all **to show the result**:


```
check_memory "warn=free < 20%" "crit=free < 10G" --show-all
page = 8.05G, physical = 7.85G
'page free'=15G;4;2 'page free %'=66%;19;9 'physical free'=4G;2;1 'physical free %'=34%;19;9
```

Changing the return syntax to include more information::

```
check_memory "top-syntax=${list}" "detail-syntax=${type} free: ${free} used: ${used} size: ${size}"
page free: 16G used: 7.98G size: 24G, physical free: 4.18G used: 7.8G size: 12G
```

Default check **via NRPE**::

```
check_nrpe --host 192.168.56.103 --command check_memory
OK memory within bounds.|'page'=531G;3;3;0;3 'page %'=12%;79;89;0;100 'physical'=530G;1;1;0;1 'physical %'=25%;79;89;0;100
```
**Overriding the unit:**

Most "byte" checks such as memory have an auto scaling feature which means values wqill go from 800M to 1.2G between checks.
Some graphing systems does not honor the units in performance data in which case you can get unexpected large values (such as 800G).
To remedy this you can lock the unit by adding `perf-config=*(unit:G)`

```
check_memory perf-config=*(unit:G)
page = 8.05G, physical = 7.85G
'page free'=15G;4;2 'page free %'=66%;19;9 'physical free'=4G;2;1 'physical free %'=34%;19;9
```



<a name="check_memory_warn"/>

<a name="check_memory_crit"/>

<a name="check_memory_debug"/>

<a name="check_memory_show-all"/>

<a name="check_memory_escape-html"/>

<a name="check_memory_help"/>

<a name="check_memory_help-pb"/>

<a name="check_memory_show-default"/>

<a name="check_memory_help-short"/>

<a name="check_memory_type"/>

<a name="check_memory_options"/>
#### Command-line Arguments


| Option                                       | Default Value      | Description                                                                                                      |
|----------------------------------------------|--------------------|------------------------------------------------------------------------------------------------------------------|
| [filter](#check_memory_filter)               |                    | Filter which marks interesting items.                                                                            |
| [warning](#check_memory_warning)             | used > 80%         | Filter which marks items which generates a warning state.                                                        |
| warn                                         |                    | Short alias for warning                                                                                          |
| [critical](#check_memory_critical)           | used > 90%         | Filter which marks items which generates a critical state.                                                       |
| crit                                         |                    | Short alias for critical.                                                                                        |
| [ok](#check_memory_ok)                       |                    | Filter which marks items which generates an ok state.                                                            |
| debug                                        | N/A                | Show debugging information in the log                                                                            |
| show-all                                     | N/A                | Show details for all matches regardless of status (normally details are only showed for warnings and criticals). |
| [empty-state](#check_memory_empty-state)     | ignored            | Return status to use when nothing matched filter.                                                                |
| [perf-config](#check_memory_perf-config)     |                    | Performance data generation configuration                                                                        |
| escape-html                                  | N/A                | Escape any < and > characters to prevent HTML encoding                                                           |
| help                                         | N/A                | Show help screen (this screen)                                                                                   |
| help-pb                                      | N/A                | Show help screen as a protocol buffer payload                                                                    |
| show-default                                 | N/A                | Show default values for a given command                                                                          |
| help-short                                   | N/A                | Show help screen (short format).                                                                                 |
| [top-syntax](#check_memory_top-syntax)       | ${status}: ${list} | Top level syntax.                                                                                                |
| [ok-syntax](#check_memory_ok-syntax)         |                    | ok syntax.                                                                                                       |
| [empty-syntax](#check_memory_empty-syntax)   |                    | Empty syntax.                                                                                                    |
| [detail-syntax](#check_memory_detail-syntax) | ${type} = ${used}  | Detail level syntax.                                                                                             |
| [perf-syntax](#check_memory_perf-syntax)     | ${type}            | Performance alias syntax.                                                                                        |
| type                                         |                    | The type of memory to check (physical = Physical memory (RAM), committed = total memory (RAM+PAGE)               |



<a name="check_memory_filter"/>
**filter:**

Filter which marks interesting items.
Interesting items are items which will be included in the check.
They do not denote warning or critical state instead it defines which items are relevant and you can remove unwanted items.





<a name="check_memory_warning"/>
**warning:**

Filter which marks items which generates a warning state.
If anything matches this filter the return status will be escalated to warning.



*Deafult Value:* | `used > 80%`



<a name="check_memory_critical"/>
**critical:**

Filter which marks items which generates a critical state.
If anything matches this filter the return status will be escalated to critical.



*Deafult Value:* | `used > 90%`



<a name="check_memory_ok"/>
**ok:**

Filter which marks items which generates an ok state.
If anything matches this any previous state for this item will be reset to ok.






<a name="check_memory_empty-state"/>
**empty-state:**

Return status to use when nothing matched filter.
If no filter is specified this will never happen unless the file is empty.


*Deafult Value:* | `ignored`



<a name="check_memory_perf-config"/>
**perf-config:**

Performance data generation configuration
TODO: obj ( key: value; key: value) obj (key:valuer;key:value)





<a name="check_memory_top-syntax"/>
**top-syntax:**

Top level syntax.
Used to format the message to return can include text as well as special keywords which will include information from the checks.
To add a keyword to the message you can use two syntaxes either ${keyword} or %(keyword) (there is no difference between them apart from ${} can be difficult to excpae on linux).


*Deafult Value:* | `${status}: ${list}`



<a name="check_memory_ok-syntax"/>
**ok-syntax:**

ok syntax.
DEPRECATED! This is the syntax for when an ok result is returned.
This value will not be used if your syntax contains %(list) or %(count).





<a name="check_memory_empty-syntax"/>
**empty-syntax:**

Empty syntax.
DEPRECATED! This is the syntax for when nothing matches the filter.





<a name="check_memory_detail-syntax"/>
**detail-syntax:**

Detail level syntax.
Used to format each resulting item in the message.
%(list) will be replaced with all the items formated by this syntax string in the top-syntax.
To add a keyword to the message you can use two syntaxes either ${keyword} or %(keyword) (there is no difference between them apart from ${} can be difficult to excpae on linux).


*Deafult Value:* | `${type} = ${used}`



<a name="check_memory_perf-syntax"/>
**perf-syntax:**

Performance alias syntax.
This is the syntax for the base names of the performance data.


*Deafult Value:* | `${type}`




<a name="check_memory_filter_keys"/>
#### Filter keywords


| Option                                       | Description                                                                                                  |
|----------------------------------------------|--------------------------------------------------------------------------------------------------------------|
| [count](#check_memory_count)                 | Number of items matching the filter. Common option for all checks.                                           |
| [crit_count](#check_memory_crit_count)       | Number of items matched the critical criteria. Common option for all checks.                                 |
| [crit_list](#check_memory_crit_list)         | A list of all items which matched the critical criteria. Common option for all checks.                       |
| [detail_list](#check_memory_detail_list)     | A special list with critical, then warning and finally ok. Common option for all checks.                     |
| [free](#check_memory_free)                   | Free memory in bytes (g,m,k,b) or percentages %                                                              |
| [free_pct](#check_memory_free_pct)           | % free memory                                                                                                |
| [list](#check_memory_list)                   | A list of all items which matched the filter. Common option for all checks.                                  |
| [ok_count](#check_memory_ok_count)           | Number of items matched the ok criteria. Common option for all checks.                                       |
| [ok_list](#check_memory_ok_list)             | A list of all items which matched the ok criteria. Common option for all checks.                             |
| [problem_count](#check_memory_problem_count) | Number of items matched either warning or critical criteria. Common option for all checks.                   |
| [problem_list](#check_memory_problem_list)   | A list of all items which matched either the critical or the warning criteria. Common option for all checks. |
| [size](#check_memory_size)                   | Total size of memory                                                                                         |
| [status](#check_memory_status)               | The returned status (OK/WARN/CRIT/UNKNOWN). Common option for all checks.                                    |
| [total](#check_memory_total)                 | Total number of items. Common option for all checks.                                                         |
| [type](#check_memory_type)                   | The type of memory to check                                                                                  |
| [used](#check_memory_used)                   | Used memory in bytes (g,m,k,b) or percentages %                                                              |
| [used_pct](#check_memory_used_pct)           | % used memory                                                                                                |
| [warn_count](#check_memory_warn_count)       | Number of items matched the warning criteria. Common option for all checks.                                  |
| [warn_list](#check_memory_warn_list)         | A list of all items which matched the warning criteria. Common option for all checks.                        |


### check_network

Check network interface status.


* [Command-line Arguments](#check_network_options)
* [Filter keywords](#check_network_filter_keys)





<a name="check_network_warn"/>

<a name="check_network_crit"/>

<a name="check_network_debug"/>

<a name="check_network_show-all"/>

<a name="check_network_escape-html"/>

<a name="check_network_help"/>

<a name="check_network_help-pb"/>

<a name="check_network_show-default"/>

<a name="check_network_help-short"/>

<a name="check_network_options"/>
#### Command-line Arguments


| Option                                        | Default Value                          | Description                                                                                                      |
|-----------------------------------------------|----------------------------------------|------------------------------------------------------------------------------------------------------------------|
| [filter](#check_network_filter)               |                                        | Filter which marks interesting items.                                                                            |
| [warning](#check_network_warning)             | total > 10000                          | Filter which marks items which generates a warning state.                                                        |
| warn                                          |                                        | Short alias for warning                                                                                          |
| [critical](#check_network_critical)           | total > 100000                         | Filter which marks items which generates a critical state.                                                       |
| crit                                          |                                        | Short alias for critical.                                                                                        |
| [ok](#check_network_ok)                       |                                        | Filter which marks items which generates an ok state.                                                            |
| debug                                         | N/A                                    | Show debugging information in the log                                                                            |
| show-all                                      | N/A                                    | Show details for all matches regardless of status (normally details are only showed for warnings and criticals). |
| [empty-state](#check_network_empty-state)     | critical                               | Return status to use when nothing matched filter.                                                                |
| [perf-config](#check_network_perf-config)     |                                        | Performance data generation configuration                                                                        |
| escape-html                                   | N/A                                    | Escape any < and > characters to prevent HTML encoding                                                           |
| help                                          | N/A                                    | Show help screen (this screen)                                                                                   |
| help-pb                                       | N/A                                    | Show help screen as a protocol buffer payload                                                                    |
| show-default                                  | N/A                                    | Show default values for a given command                                                                          |
| help-short                                    | N/A                                    | Show help screen (short format).                                                                                 |
| [top-syntax](#check_network_top-syntax)       | ${status}: ${list}                     | Top level syntax.                                                                                                |
| [ok-syntax](#check_network_ok-syntax)         | %(status): Network interfaces seem ok. | ok syntax.                                                                                                       |
| [empty-syntax](#check_network_empty-syntax)   |                                        | Empty syntax.                                                                                                    |
| [detail-syntax](#check_network_detail-syntax) | ${name} >${sent} <${received} bps      | Detail level syntax.                                                                                             |
| [perf-syntax](#check_network_perf-syntax)     | ${name}                                | Performance alias syntax.                                                                                        |



<a name="check_network_filter"/>
**filter:**

Filter which marks interesting items.
Interesting items are items which will be included in the check.
They do not denote warning or critical state instead it defines which items are relevant and you can remove unwanted items.





<a name="check_network_warning"/>
**warning:**

Filter which marks items which generates a warning state.
If anything matches this filter the return status will be escalated to warning.



*Deafult Value:* | `total > 10000`



<a name="check_network_critical"/>
**critical:**

Filter which marks items which generates a critical state.
If anything matches this filter the return status will be escalated to critical.



*Deafult Value:* | `total > 100000`



<a name="check_network_ok"/>
**ok:**

Filter which marks items which generates an ok state.
If anything matches this any previous state for this item will be reset to ok.






<a name="check_network_empty-state"/>
**empty-state:**

Return status to use when nothing matched filter.
If no filter is specified this will never happen unless the file is empty.


*Deafult Value:* | `critical`



<a name="check_network_perf-config"/>
**perf-config:**

Performance data generation configuration
TODO: obj ( key: value; key: value) obj (key:valuer;key:value)





<a name="check_network_top-syntax"/>
**top-syntax:**

Top level syntax.
Used to format the message to return can include text as well as special keywords which will include information from the checks.
To add a keyword to the message you can use two syntaxes either ${keyword} or %(keyword) (there is no difference between them apart from ${} can be difficult to excpae on linux).


*Deafult Value:* | `${status}: ${list}`



<a name="check_network_ok-syntax"/>
**ok-syntax:**

ok syntax.
DEPRECATED! This is the syntax for when an ok result is returned.
This value will not be used if your syntax contains %(list) or %(count).


*Deafult Value:* | `%(status): Network interfaces seem ok.`



<a name="check_network_empty-syntax"/>
**empty-syntax:**

Empty syntax.
DEPRECATED! This is the syntax for when nothing matches the filter.





<a name="check_network_detail-syntax"/>
**detail-syntax:**

Detail level syntax.
Used to format each resulting item in the message.
%(list) will be replaced with all the items formated by this syntax string in the top-syntax.
To add a keyword to the message you can use two syntaxes either ${keyword} or %(keyword) (there is no difference between them apart from ${} can be difficult to excpae on linux).


*Deafult Value:* | `${name} >${sent} <${received} bps`



<a name="check_network_perf-syntax"/>
**perf-syntax:**

Performance alias syntax.
This is the syntax for the base names of the performance data.


*Deafult Value:* | `${name}`




<a name="check_network_filter_keys"/>
#### Filter keywords


| Option                                                | Description                                                                                                  |
|-------------------------------------------------------|--------------------------------------------------------------------------------------------------------------|
| [MAC](#check_network_MAC)                             | The MAC address                                                                                              |
| [count](#check_network_count)                         | Number of items matching the filter. Common option for all checks.                                           |
| [crit_count](#check_network_crit_count)               | Number of items matched the critical criteria. Common option for all checks.                                 |
| [crit_list](#check_network_crit_list)                 | A list of all items which matched the critical criteria. Common option for all checks.                       |
| [detail_list](#check_network_detail_list)             | A special list with critical, then warning and finally ok. Common option for all checks.                     |
| [enabled](#check_network_enabled)                     | True if the network interface is enabled                                                                     |
| [list](#check_network_list)                           | A list of all items which matched the filter. Common option for all checks.                                  |
| [name](#check_network_name)                           | Network interface name                                                                                       |
| [net_connection_id](#check_network_net_connection_id) | Network connection id                                                                                        |
| [ok_count](#check_network_ok_count)                   | Number of items matched the ok criteria. Common option for all checks.                                       |
| [ok_list](#check_network_ok_list)                     | A list of all items which matched the ok criteria. Common option for all checks.                             |
| [problem_count](#check_network_problem_count)         | Number of items matched either warning or critical criteria. Common option for all checks.                   |
| [problem_list](#check_network_problem_list)           | A list of all items which matched either the critical or the warning criteria. Common option for all checks. |
| [received](#check_network_received)                   | Bytes received per second                                                                                    |
| [sent](#check_network_sent)                           | Bytes sent per second                                                                                        |
| [speed](#check_network_speed)                         | The network interface speed                                                                                  |
| [status](#check_network_status)                       | The returned status (OK/WARN/CRIT/UNKNOWN). Common option for all checks.                                    |
| [total](#check_network_total)                         | Total number of items. Common option for all checks.                                                         |
| [warn_count](#check_network_warn_count)               | Number of items matched the warning criteria. Common option for all checks.                                  |
| [warn_list](#check_network_warn_list)                 | A list of all items which matched the warning criteria. Common option for all checks.                        |


### check_os_version

Check the version of the underlaying OS.

* [Samples](#check_os_version_samples)

* [Command-line Arguments](#check_os_version_options)
* [Filter keywords](#check_os_version_filter_keys)


<a name="check_os_version_samples"/>
#### Sample Commands

_To edit these sample please edit [this page](https://github.com/mickem/nscp-docs/blob/master/samples/CheckSystem_check_os_version_samples.md)_

**Default check:**

```
check_os_Version
L     client CRITICAL: Windows 7 (6.1.7601)
L     client  Performance data: 'version'=61;50;50
```

Making sure the OS version is **Windows 8**:

```
check_os_Version "warn=version < 62"
L     client WARNING: Windows 7 (6.1.7601)
L     client  Performance data: 'version'=61;62;0
```

Default check **via NRPE**:

```
check_nrpe --host 192.168.56.103 --command check_os_version
Windows 2012 (6.2.9200)|'version'=62;50;50
```




<a name="check_os_version_warn"/>

<a name="check_os_version_crit"/>

<a name="check_os_version_debug"/>

<a name="check_os_version_show-all"/>

<a name="check_os_version_escape-html"/>

<a name="check_os_version_help"/>

<a name="check_os_version_help-pb"/>

<a name="check_os_version_show-default"/>

<a name="check_os_version_help-short"/>

<a name="check_os_version_options"/>
#### Command-line Arguments


| Option                                           | Default Value                           | Description                                                                                                      |
|--------------------------------------------------|-----------------------------------------|------------------------------------------------------------------------------------------------------------------|
| [filter](#check_os_version_filter)               |                                         | Filter which marks interesting items.                                                                            |
| [warning](#check_os_version_warning)             | version <= 50                           | Filter which marks items which generates a warning state.                                                        |
| warn                                             |                                         | Short alias for warning                                                                                          |
| [critical](#check_os_version_critical)           | version <= 50                           | Filter which marks items which generates a critical state.                                                       |
| crit                                             |                                         | Short alias for critical.                                                                                        |
| [ok](#check_os_version_ok)                       |                                         | Filter which marks items which generates an ok state.                                                            |
| debug                                            | N/A                                     | Show debugging information in the log                                                                            |
| show-all                                         | N/A                                     | Show details for all matches regardless of status (normally details are only showed for warnings and criticals). |
| [empty-state](#check_os_version_empty-state)     | ignored                                 | Return status to use when nothing matched filter.                                                                |
| [perf-config](#check_os_version_perf-config)     |                                         | Performance data generation configuration                                                                        |
| escape-html                                      | N/A                                     | Escape any < and > characters to prevent HTML encoding                                                           |
| help                                             | N/A                                     | Show help screen (this screen)                                                                                   |
| help-pb                                          | N/A                                     | Show help screen as a protocol buffer payload                                                                    |
| show-default                                     | N/A                                     | Show default values for a given command                                                                          |
| help-short                                       | N/A                                     | Show help screen (short format).                                                                                 |
| [top-syntax](#check_os_version_top-syntax)       | ${status}: ${list}                      | Top level syntax.                                                                                                |
| [ok-syntax](#check_os_version_ok-syntax)         |                                         | ok syntax.                                                                                                       |
| [empty-syntax](#check_os_version_empty-syntax)   |                                         | Empty syntax.                                                                                                    |
| [detail-syntax](#check_os_version_detail-syntax) | ${version} (${major}.${minor}.${build}) | Detail level syntax.                                                                                             |
| [perf-syntax](#check_os_version_perf-syntax)     | version                                 | Performance alias syntax.                                                                                        |



<a name="check_os_version_filter"/>
**filter:**

Filter which marks interesting items.
Interesting items are items which will be included in the check.
They do not denote warning or critical state instead it defines which items are relevant and you can remove unwanted items.





<a name="check_os_version_warning"/>
**warning:**

Filter which marks items which generates a warning state.
If anything matches this filter the return status will be escalated to warning.



*Deafult Value:* | `version <= 50`



<a name="check_os_version_critical"/>
**critical:**

Filter which marks items which generates a critical state.
If anything matches this filter the return status will be escalated to critical.



*Deafult Value:* | `version <= 50`



<a name="check_os_version_ok"/>
**ok:**

Filter which marks items which generates an ok state.
If anything matches this any previous state for this item will be reset to ok.






<a name="check_os_version_empty-state"/>
**empty-state:**

Return status to use when nothing matched filter.
If no filter is specified this will never happen unless the file is empty.


*Deafult Value:* | `ignored`



<a name="check_os_version_perf-config"/>
**perf-config:**

Performance data generation configuration
TODO: obj ( key: value; key: value) obj (key:valuer;key:value)





<a name="check_os_version_top-syntax"/>
**top-syntax:**

Top level syntax.
Used to format the message to return can include text as well as special keywords which will include information from the checks.
To add a keyword to the message you can use two syntaxes either ${keyword} or %(keyword) (there is no difference between them apart from ${} can be difficult to excpae on linux).


*Deafult Value:* | `${status}: ${list}`



<a name="check_os_version_ok-syntax"/>
**ok-syntax:**

ok syntax.
DEPRECATED! This is the syntax for when an ok result is returned.
This value will not be used if your syntax contains %(list) or %(count).





<a name="check_os_version_empty-syntax"/>
**empty-syntax:**

Empty syntax.
DEPRECATED! This is the syntax for when nothing matches the filter.





<a name="check_os_version_detail-syntax"/>
**detail-syntax:**

Detail level syntax.
Used to format each resulting item in the message.
%(list) will be replaced with all the items formated by this syntax string in the top-syntax.
To add a keyword to the message you can use two syntaxes either ${keyword} or %(keyword) (there is no difference between them apart from ${} can be difficult to excpae on linux).


*Deafult Value:* | `${version} (${major}.${minor}.${build})`



<a name="check_os_version_perf-syntax"/>
**perf-syntax:**

Performance alias syntax.
This is the syntax for the base names of the performance data.


*Deafult Value:* | `version`




<a name="check_os_version_filter_keys"/>
#### Filter keywords


| Option                                           | Description                                                                                                                                                                                                                                                           |
|--------------------------------------------------|-----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|
| [build](#check_os_version_build)                 | Build version number                                                                                                                                                                                                                                                  |
| [count](#check_os_version_count)                 | Number of items matching the filter. Common option for all checks.                                                                                                                                                                                                    |
| [crit_count](#check_os_version_crit_count)       | Number of items matched the critical criteria. Common option for all checks.                                                                                                                                                                                          |
| [crit_list](#check_os_version_crit_list)         | A list of all items which matched the critical criteria. Common option for all checks.                                                                                                                                                                                |
| [detail_list](#check_os_version_detail_list)     | A special list with critical, then warning and finally ok. Common option for all checks.                                                                                                                                                                              |
| [list](#check_os_version_list)                   | A list of all items which matched the filter. Common option for all checks.                                                                                                                                                                                           |
| [major](#check_os_version_major)                 | Major version number                                                                                                                                                                                                                                                  |
| [minor](#check_os_version_minor)                 | Minor version number                                                                                                                                                                                                                                                  |
| [ok_count](#check_os_version_ok_count)           | Number of items matched the ok criteria. Common option for all checks.                                                                                                                                                                                                |
| [ok_list](#check_os_version_ok_list)             | A list of all items which matched the ok criteria. Common option for all checks.                                                                                                                                                                                      |
| [problem_count](#check_os_version_problem_count) | Number of items matched either warning or critical criteria. Common option for all checks.                                                                                                                                                                            |
| [problem_list](#check_os_version_problem_list)   | A list of all items which matched either the critical or the warning criteria. Common option for all checks.                                                                                                                                                          |
| [status](#check_os_version_status)               | The returned status (OK/WARN/CRIT/UNKNOWN). Common option for all checks.                                                                                                                                                                                             |
| [suite](#check_os_version_suite)                 | Which suites are installed on the machine (Microsoft BackOffice, Web Edition, Compute Cluster Edition, Datacenter Edition, Enterprise Edition, Embedded, Home Edition, Remote Desktop Support, Small Business Server, Storage Server, Terminal Services, Home Server) |
| [total](#check_os_version_total)                 | Total number of items. Common option for all checks.                                                                                                                                                                                                                  |
| [version](#check_os_version_version)             | The system version                                                                                                                                                                                                                                                    |
| [warn_count](#check_os_version_warn_count)       | Number of items matched the warning criteria. Common option for all checks.                                                                                                                                                                                           |
| [warn_list](#check_os_version_warn_list)         | A list of all items which matched the warning criteria. Common option for all checks.                                                                                                                                                                                 |


### check_pagefile

Check the size of the system pagefile(s).

* [Samples](#check_pagefile_samples)

* [Command-line Arguments](#check_pagefile_options)
* [Filter keywords](#check_pagefile_filter_keys)


<a name="check_pagefile_samples"/>
#### Sample Commands

_To edit these sample please edit [this page](https://github.com/mickem/nscp-docs/blob/master/samples/CheckSystem_check_pagefile_samples.md)_

**Default options:**

```
check_pagefile
L     client WARNING: \Device\HarddiskVolume2\pagefile.sys 24.3M (32M)
L     client  Performance data: '\??\D:\pagefile.sys'=1G;14;19;0;23 '\??\D:\pagefile.sys %'=6%;59;79;0;100 '\Device\HarddiskVolume2\pagefile.sys'=24M;19;25;0;32 '\Device\HarddiskVolume2\pagefile.sys %'=75%;59;79;0;100 'total'=1G;14;19;0;23 'total %'=6%;59;79;0;100
```

Only showing the total amount of pagefile usage::

```
check_pagefile "filter=name = 'total'" "top-syntax=${list}"
OK: total 1.66G (24G)
Performance data: 'total'=1G;14;19;0;23 'total %'=6%;59;79;0;100

```

Getting help on avalible options::

```
check_pagefile help
...
  filter=ARG           Filter which marks interesting items.
					   Interesting items are items which will be included in
					   the check.
					   They do not denote warning or critical state but they
					   are checked use this to filter out unwanted items.
						   Avalible options:
					   free          Free memory in bytes (g,m,k,b) or percentages %
					   name          The name of the page file (location)
					   size          Total size of pagefile
					   used          Used memory in bytes (g,m,k,b) or percentages %
					   count         Number of items matching the filter
					   total         Total number of items
					   ok_count      Number of items matched the ok criteria
					   warn_count    Number of items matched the warning criteria
					   crit_count    Number of items matched the critical criteria
					   problem_count Number of items matched either warning or critical criteria
...
```



<a name="check_pagefile_warn"/>

<a name="check_pagefile_crit"/>

<a name="check_pagefile_debug"/>

<a name="check_pagefile_show-all"/>

<a name="check_pagefile_escape-html"/>

<a name="check_pagefile_help"/>

<a name="check_pagefile_help-pb"/>

<a name="check_pagefile_show-default"/>

<a name="check_pagefile_help-short"/>

<a name="check_pagefile_options"/>
#### Command-line Arguments


| Option                                         | Default Value             | Description                                                                                                      |
|------------------------------------------------|---------------------------|------------------------------------------------------------------------------------------------------------------|
| [filter](#check_pagefile_filter)               |                           | Filter which marks interesting items.                                                                            |
| [warning](#check_pagefile_warning)             | used > 60%                | Filter which marks items which generates a warning state.                                                        |
| warn                                           |                           | Short alias for warning                                                                                          |
| [critical](#check_pagefile_critical)           | used > 80%                | Filter which marks items which generates a critical state.                                                       |
| crit                                           |                           | Short alias for critical.                                                                                        |
| [ok](#check_pagefile_ok)                       |                           | Filter which marks items which generates an ok state.                                                            |
| debug                                          | N/A                       | Show debugging information in the log                                                                            |
| show-all                                       | N/A                       | Show details for all matches regardless of status (normally details are only showed for warnings and criticals). |
| [empty-state](#check_pagefile_empty-state)     | ignored                   | Return status to use when nothing matched filter.                                                                |
| [perf-config](#check_pagefile_perf-config)     |                           | Performance data generation configuration                                                                        |
| escape-html                                    | N/A                       | Escape any < and > characters to prevent HTML encoding                                                           |
| help                                           | N/A                       | Show help screen (this screen)                                                                                   |
| help-pb                                        | N/A                       | Show help screen as a protocol buffer payload                                                                    |
| show-default                                   | N/A                       | Show default values for a given command                                                                          |
| help-short                                     | N/A                       | Show help screen (short format).                                                                                 |
| [top-syntax](#check_pagefile_top-syntax)       | ${status}: ${list}        | Top level syntax.                                                                                                |
| [ok-syntax](#check_pagefile_ok-syntax)         |                           | ok syntax.                                                                                                       |
| [empty-syntax](#check_pagefile_empty-syntax)   |                           | Empty syntax.                                                                                                    |
| [detail-syntax](#check_pagefile_detail-syntax) | ${name} ${used} (${size}) | Detail level syntax.                                                                                             |
| [perf-syntax](#check_pagefile_perf-syntax)     | ${name}                   | Performance alias syntax.                                                                                        |



<a name="check_pagefile_filter"/>
**filter:**

Filter which marks interesting items.
Interesting items are items which will be included in the check.
They do not denote warning or critical state instead it defines which items are relevant and you can remove unwanted items.





<a name="check_pagefile_warning"/>
**warning:**

Filter which marks items which generates a warning state.
If anything matches this filter the return status will be escalated to warning.



*Deafult Value:* | `used > 60%`



<a name="check_pagefile_critical"/>
**critical:**

Filter which marks items which generates a critical state.
If anything matches this filter the return status will be escalated to critical.



*Deafult Value:* | `used > 80%`



<a name="check_pagefile_ok"/>
**ok:**

Filter which marks items which generates an ok state.
If anything matches this any previous state for this item will be reset to ok.






<a name="check_pagefile_empty-state"/>
**empty-state:**

Return status to use when nothing matched filter.
If no filter is specified this will never happen unless the file is empty.


*Deafult Value:* | `ignored`



<a name="check_pagefile_perf-config"/>
**perf-config:**

Performance data generation configuration
TODO: obj ( key: value; key: value) obj (key:valuer;key:value)





<a name="check_pagefile_top-syntax"/>
**top-syntax:**

Top level syntax.
Used to format the message to return can include text as well as special keywords which will include information from the checks.
To add a keyword to the message you can use two syntaxes either ${keyword} or %(keyword) (there is no difference between them apart from ${} can be difficult to excpae on linux).


*Deafult Value:* | `${status}: ${list}`



<a name="check_pagefile_ok-syntax"/>
**ok-syntax:**

ok syntax.
DEPRECATED! This is the syntax for when an ok result is returned.
This value will not be used if your syntax contains %(list) or %(count).





<a name="check_pagefile_empty-syntax"/>
**empty-syntax:**

Empty syntax.
DEPRECATED! This is the syntax for when nothing matches the filter.





<a name="check_pagefile_detail-syntax"/>
**detail-syntax:**

Detail level syntax.
Used to format each resulting item in the message.
%(list) will be replaced with all the items formated by this syntax string in the top-syntax.
To add a keyword to the message you can use two syntaxes either ${keyword} or %(keyword) (there is no difference between them apart from ${} can be difficult to excpae on linux).


*Deafult Value:* | `${name} ${used} (${size})`



<a name="check_pagefile_perf-syntax"/>
**perf-syntax:**

Performance alias syntax.
This is the syntax for the base names of the performance data.


*Deafult Value:* | `${name}`




<a name="check_pagefile_filter_keys"/>
#### Filter keywords


| Option                                         | Description                                                                                                  |
|------------------------------------------------|--------------------------------------------------------------------------------------------------------------|
| [count](#check_pagefile_count)                 | Number of items matching the filter. Common option for all checks.                                           |
| [crit_count](#check_pagefile_crit_count)       | Number of items matched the critical criteria. Common option for all checks.                                 |
| [crit_list](#check_pagefile_crit_list)         | A list of all items which matched the critical criteria. Common option for all checks.                       |
| [detail_list](#check_pagefile_detail_list)     | A special list with critical, then warning and finally ok. Common option for all checks.                     |
| [free](#check_pagefile_free)                   | Free memory in bytes (g,m,k,b) or percentages %                                                              |
| [free_pct](#check_pagefile_free_pct)           | % free memory                                                                                                |
| [list](#check_pagefile_list)                   | A list of all items which matched the filter. Common option for all checks.                                  |
| [name](#check_pagefile_name)                   | The name of the page file (location)                                                                         |
| [ok_count](#check_pagefile_ok_count)           | Number of items matched the ok criteria. Common option for all checks.                                       |
| [ok_list](#check_pagefile_ok_list)             | A list of all items which matched the ok criteria. Common option for all checks.                             |
| [problem_count](#check_pagefile_problem_count) | Number of items matched either warning or critical criteria. Common option for all checks.                   |
| [problem_list](#check_pagefile_problem_list)   | A list of all items which matched either the critical or the warning criteria. Common option for all checks. |
| [size](#check_pagefile_size)                   | Total size of pagefile                                                                                       |
| [status](#check_pagefile_status)               | The returned status (OK/WARN/CRIT/UNKNOWN). Common option for all checks.                                    |
| [total](#check_pagefile_total)                 | Total number of items. Common option for all checks.                                                         |
| [used](#check_pagefile_used)                   | Used memory in bytes (g,m,k,b) or percentages %                                                              |
| [used_pct](#check_pagefile_used_pct)           | % used memory                                                                                                |
| [warn_count](#check_pagefile_warn_count)       | Number of items matched the warning criteria. Common option for all checks.                                  |
| [warn_list](#check_pagefile_warn_list)         | A list of all items which matched the warning criteria. Common option for all checks.                        |


### check_pdh

Check the value of a performance (PDH) counter on the local or remote system.
The counters can also be added and polled periodcally to get average values. Performance Log Users group membership is required to check performance counters.

* [Samples](#check_pdh_samples)

* [Command-line Arguments](#check_pdh_options)
* [Filter keywords](#check_pdh_filter_keys)


<a name="check_pdh_samples"/>
#### Sample Commands

_To edit these sample please edit [this page](https://github.com/mickem/nscp-docs/blob/master/samples/CheckSystem_check_pdh_samples.md)_

﻿**Checking specific Counter (\System\System Up Time):**

```
check_pdh "counter=\\System\\System Up Time" "warn=value > 5" "crit=value > 9999"
\System\System Up Time = 204213
'\System\System Up Time value'=204213;5;9999
```

Using the **expand index** to check for translated counters::

```
check_pdh "counter=\\4\\30" "warn=value > 5" "crit=value > 9999" expand-index
Everything looks good
'\Minne\Dedikationsgräns value'=-2147483648;5;9999
```

Checking **translated counters** without expanding indexes::

```
check_pdh "counter=\\4\\30" "warn=value > 5" "crit=value > 9999"
Everything looks good
'\4\30 value'=-2147483648;5;9999
```

Checking **large values** using the type=large keyword::

```
check_pdh "counter=\\4\\30" "warn=value > 5" "crit=value > 9999" flags=nocap100 expand-index type=large
\Minne\Dedikationsgräns = 25729224704
'\Minne\Dedikationsgräns value'=25729224704;5;9999
```

Using real-time checks to check avergae values over time.

Here we configure a counter to be checked at regular intervals and the value is added to a rrd buffer.
The configuration from nsclient.ini::

```
[/settings/system/windows/counters/foo]
collection strategy=rrd
type=large
counter=\Processor(_total)\% Processor Time
```

Then we can check the value (**current snapshot**)::

```
check_pdh "counter=foo" "warn=value > 80" "crit=value > 90"
Everything looks good
'foo value'=18;80;90
```

To check averages from the same counter we need to specify the time option::

```
check_pdh "counter=foo" "warn=value > 80" "crit=value > 90" time=30s
Everything looks good
'foo value'=3;80;90
```

Checking **all instances** of a given counter::

```
    check_pdh "counter=\Processor(*)\% processortid" instances
L     client OK: \\MIME-LAPTOP\Processor(0)\% processortid = 100, \\MIME-LAPTOP\Processor(1)\% processortid = 100, \\MIME-LAPTOP\Processor(2)\% processortid = 100, \\MIME-LAPTOP\Processor(3)\% processortid = 100, \\MIME-LAPTOP\Processor(4)\% processortid = 100, \\MIME-LAPTOP\Processor(5)\% processortid = 100, \\MIME-LAPTOP\Processor(6)\% processortid = 100, \\MIME-LAPTOP\Processor(7)\% processortid = 100, \\MIME-LAPTOP\Processor(_Total)\% processortid = 100
    L     client  Performance data: '\Processor(*)\% processortid_0'=100;0;0 '\Processor(*)\% processortid_1'=100;0;0 '\Processor(*)\% processortid_2'=100;0;0 '\Processor(*)\% processortid_3'=100;0;0 '\Processor(*)\% processortid_4'=100;0;0 '\Processor(*)\% processortid_5'=100;0;0 '\Processor(*)\% processortid_6'=100;0;0 '\Processor(*)\% processortid_7'=100;0;0 '\Processor(*)\% processortid__Total'=100;0;0
```



<a name="check_pdh_warn"/>

<a name="check_pdh_crit"/>

<a name="check_pdh_debug"/>

<a name="check_pdh_show-all"/>

<a name="check_pdh_escape-html"/>

<a name="check_pdh_help"/>

<a name="check_pdh_help-pb"/>

<a name="check_pdh_show-default"/>

<a name="check_pdh_help-short"/>

<a name="check_pdh_counter"/>

<a name="check_pdh_expand-index"/>

<a name="check_pdh_instances"/>

<a name="check_pdh_reload"/>

<a name="check_pdh_averages"/>

<a name="check_pdh_time"/>

<a name="check_pdh_flags"/>

<a name="check_pdh_ignore-errors"/>

<a name="check_pdh_options"/>
#### Command-line Arguments


| Option                                    | Default Value       | Description                                                                                                                          |
|-------------------------------------------|---------------------|--------------------------------------------------------------------------------------------------------------------------------------|
| [filter](#check_pdh_filter)               |                     | Filter which marks interesting items.                                                                                                |
| [warning](#check_pdh_warning)             |                     | Filter which marks items which generates a warning state.                                                                            |
| warn                                      |                     | Short alias for warning                                                                                                              |
| [critical](#check_pdh_critical)           |                     | Filter which marks items which generates a critical state.                                                                           |
| crit                                      |                     | Short alias for critical.                                                                                                            |
| [ok](#check_pdh_ok)                       |                     | Filter which marks items which generates an ok state.                                                                                |
| debug                                     | N/A                 | Show debugging information in the log                                                                                                |
| show-all                                  | N/A                 | Show details for all matches regardless of status (normally details are only showed for warnings and criticals).                     |
| [empty-state](#check_pdh_empty-state)     | unknown             | Return status to use when nothing matched filter.                                                                                    |
| [perf-config](#check_pdh_perf-config)     |                     | Performance data generation configuration                                                                                            |
| escape-html                               | N/A                 | Escape any < and > characters to prevent HTML encoding                                                                               |
| help                                      | N/A                 | Show help screen (this screen)                                                                                                       |
| help-pb                                   | N/A                 | Show help screen as a protocol buffer payload                                                                                        |
| show-default                              | N/A                 | Show default values for a given command                                                                                              |
| help-short                                | N/A                 | Show help screen (short format).                                                                                                     |
| [top-syntax](#check_pdh_top-syntax)       | ${status}: ${list}  | Top level syntax.                                                                                                                    |
| [ok-syntax](#check_pdh_ok-syntax)         |                     | ok syntax.                                                                                                                           |
| [empty-syntax](#check_pdh_empty-syntax)   |                     | Empty syntax.                                                                                                                        |
| [detail-syntax](#check_pdh_detail-syntax) | ${alias} = ${value} | Detail level syntax.                                                                                                                 |
| [perf-syntax](#check_pdh_perf-syntax)     | ${alias}            | Performance alias syntax.                                                                                                            |
| counter                                   |                     | Performance counter to check                                                                                                         |
| expand-index                              | N/A                 | Expand indexes in counter strings                                                                                                    |
| instances                                 | N/A                 | Expand wildcards and fetch all instances                                                                                             |
| reload                                    | N/A                 | Reload counters on errors (useful to check counters which are not added at boot)                                                     |
| averages                                  | N/A                 | Check average values (ie. wait for 1 second to collecting two samples)                                                               |
| time                                      |                     | Timeframe to use for named rrd counters                                                                                              |
| flags                                     |                     | Extra flags to configure the counter (nocap100, 1000, noscale)                                                                       |
| [type](#check_pdh_type)                   | large               | Format of value (double, long, large)                                                                                                |
| ignore-errors                             | N/A                 | If we should ignore errors when checking counters, for instance missing counters or invalid counters will return 0 instead of errors |



<a name="check_pdh_filter"/>
**filter:**

Filter which marks interesting items.
Interesting items are items which will be included in the check.
They do not denote warning or critical state instead it defines which items are relevant and you can remove unwanted items.





<a name="check_pdh_warning"/>
**warning:**

Filter which marks items which generates a warning state.
If anything matches this filter the return status will be escalated to warning.






<a name="check_pdh_critical"/>
**critical:**

Filter which marks items which generates a critical state.
If anything matches this filter the return status will be escalated to critical.






<a name="check_pdh_ok"/>
**ok:**

Filter which marks items which generates an ok state.
If anything matches this any previous state for this item will be reset to ok.






<a name="check_pdh_empty-state"/>
**empty-state:**

Return status to use when nothing matched filter.
If no filter is specified this will never happen unless the file is empty.


*Deafult Value:* | `unknown`



<a name="check_pdh_perf-config"/>
**perf-config:**

Performance data generation configuration
TODO: obj ( key: value; key: value) obj (key:valuer;key:value)





<a name="check_pdh_top-syntax"/>
**top-syntax:**

Top level syntax.
Used to format the message to return can include text as well as special keywords which will include information from the checks.
To add a keyword to the message you can use two syntaxes either ${keyword} or %(keyword) (there is no difference between them apart from ${} can be difficult to excpae on linux).


*Deafult Value:* | `${status}: ${list}`



<a name="check_pdh_ok-syntax"/>
**ok-syntax:**

ok syntax.
DEPRECATED! This is the syntax for when an ok result is returned.
This value will not be used if your syntax contains %(list) or %(count).





<a name="check_pdh_empty-syntax"/>
**empty-syntax:**

Empty syntax.
DEPRECATED! This is the syntax for when nothing matches the filter.





<a name="check_pdh_detail-syntax"/>
**detail-syntax:**

Detail level syntax.
Used to format each resulting item in the message.
%(list) will be replaced with all the items formated by this syntax string in the top-syntax.
To add a keyword to the message you can use two syntaxes either ${keyword} or %(keyword) (there is no difference between them apart from ${} can be difficult to excpae on linux).


*Deafult Value:* | `${alias} = ${value}`



<a name="check_pdh_perf-syntax"/>
**perf-syntax:**

Performance alias syntax.
This is the syntax for the base names of the performance data.


*Deafult Value:* | `${alias}`



<a name="check_pdh_type"/>
**type:**

Format of value (double, long, large)


*Deafult Value:* | `large`




<a name="check_pdh_filter_keys"/>
#### Filter keywords


| Option                                    | Description                                                                                                  |
|-------------------------------------------|--------------------------------------------------------------------------------------------------------------|
| [alias](#check_pdh_alias)                 | The counter alias                                                                                            |
| [count](#check_pdh_count)                 | Number of items matching the filter. Common option for all checks.                                           |
| [counter](#check_pdh_counter)             | The counter name                                                                                             |
| [crit_count](#check_pdh_crit_count)       | Number of items matched the critical criteria. Common option for all checks.                                 |
| [crit_list](#check_pdh_crit_list)         | A list of all items which matched the critical criteria. Common option for all checks.                       |
| [detail_list](#check_pdh_detail_list)     | A special list with critical, then warning and finally ok. Common option for all checks.                     |
| [list](#check_pdh_list)                   | A list of all items which matched the filter. Common option for all checks.                                  |
| [ok_count](#check_pdh_ok_count)           | Number of items matched the ok criteria. Common option for all checks.                                       |
| [ok_list](#check_pdh_ok_list)             | A list of all items which matched the ok criteria. Common option for all checks.                             |
| [problem_count](#check_pdh_problem_count) | Number of items matched either warning or critical criteria. Common option for all checks.                   |
| [problem_list](#check_pdh_problem_list)   | A list of all items which matched either the critical or the warning criteria. Common option for all checks. |
| [status](#check_pdh_status)               | The returned status (OK/WARN/CRIT/UNKNOWN). Common option for all checks.                                    |
| [time](#check_pdh_time)                   | The time for rrd checks                                                                                      |
| [total](#check_pdh_total)                 | Total number of items. Common option for all checks.                                                         |
| [value](#check_pdh_value)                 | The counter value (either float or int)                                                                      |
| [value_f](#check_pdh_value_f)             | The counter value (force float value)                                                                        |
| [value_i](#check_pdh_value_i)             | The counter value (force int value)                                                                          |
| [warn_count](#check_pdh_warn_count)       | Number of items matched the warning criteria. Common option for all checks.                                  |
| [warn_list](#check_pdh_warn_list)         | A list of all items which matched the warning criteria. Common option for all checks.                        |


### check_process

Check state/metrics of one or more of the processes running on the computer.

* [Samples](#check_process_samples)

* [Command-line Arguments](#check_process_options)
* [Filter keywords](#check_process_filter_keys)


<a name="check_process_samples"/>
#### Sample Commands

_To edit these sample please edit [this page](https://github.com/mickem/nscp-docs/blob/master/samples/CheckSystem_check_process_samples.md)_

**Default check:**

```
check_process
SetPoint.exe=hung
Performance data: 'taskhost.exe'=1;1;0 'dwm.exe'=1;1;0 'explorer.exe'=1;1;0 ... 'chrome.exe'=1;1;0 'vcpkgsrv.exe'=1;1;0 'vcpkgsrv.exe'=1;1;0 
```

Default check **via NRPE**::

```
check_nrpe --host 192.168.56.103 --command check_process
SetPoint.exe=hung|'smss.exe state'=1;0;0 'csrss.exe state'=1;0;0...
```

Check that **specific process** are running::

```
check_process process=explorer.exe process=foo.exe
foo.exe=stopped
Performance data: 'explorer.exe'=1;1;0 'foo.exe'=0;1;0
```

Check **memory footprint** from specific processes::

```
check_process process=explorer.exe "warn=working_set > 70m"
explorer.exe=started
Performance data: 'explorer.exe ws_size'=73M;70;0
```

**Extend the syntax** to display the attributes we are interested in::

```
check_process process=explorer.exe "warn=working_set > 70m" "detail-syntax=${exe} ws:${working_set}, handles: ${handles}, user time:${user}s"
explorer.exe ws:77271040, handles: 800, user time:107s
Performance data: 'explorer.exe ws_size'=73M;70;0
```

List all processes which use **more then 200m virtual memory** Default check **via NRPE**::

```
check_nrpe --host 192.168.56.103 --command check_process --arguments "filter=virtual > 200m"
OK all processes are ok.|'csrss.exe state'=1;0;0 'svchost.exe state'=1;0;0 'AvastSvc.exe state'=1;0;0 ...
```




<a name="check_process_warn"/>

<a name="check_process_crit"/>

<a name="check_process_debug"/>

<a name="check_process_show-all"/>

<a name="check_process_escape-html"/>

<a name="check_process_help"/>

<a name="check_process_help-pb"/>

<a name="check_process_show-default"/>

<a name="check_process_help-short"/>

<a name="check_process_process"/>

<a name="check_process_scan-info"/>

<a name="check_process_scan-16bit"/>

<a name="check_process_scan-unreadable"/>

<a name="check_process_total"/>

<a name="check_process_options"/>
#### Command-line Arguments


| Option                                        | Default Value                    | Description                                                                                                      |
|-----------------------------------------------|----------------------------------|------------------------------------------------------------------------------------------------------------------|
| [filter](#check_process_filter)               | state != 'unreadable'            | Filter which marks interesting items.                                                                            |
| [warning](#check_process_warning)             | state not in ('started')         | Filter which marks items which generates a warning state.                                                        |
| warn                                          |                                  | Short alias for warning                                                                                          |
| [critical](#check_process_critical)           | state = 'stopped', count = 0     | Filter which marks items which generates a critical state.                                                       |
| crit                                          |                                  | Short alias for critical.                                                                                        |
| [ok](#check_process_ok)                       |                                  | Filter which marks items which generates an ok state.                                                            |
| debug                                         | N/A                              | Show debugging information in the log                                                                            |
| show-all                                      | N/A                              | Show details for all matches regardless of status (normally details are only showed for warnings and criticals). |
| [empty-state](#check_process_empty-state)     | unknown                          | Return status to use when nothing matched filter.                                                                |
| [perf-config](#check_process_perf-config)     |                                  | Performance data generation configuration                                                                        |
| escape-html                                   | N/A                              | Escape any < and > characters to prevent HTML encoding                                                           |
| help                                          | N/A                              | Show help screen (this screen)                                                                                   |
| help-pb                                       | N/A                              | Show help screen as a protocol buffer payload                                                                    |
| show-default                                  | N/A                              | Show default values for a given command                                                                          |
| help-short                                    | N/A                              | Show help screen (short format).                                                                                 |
| [top-syntax](#check_process_top-syntax)       | ${status}: ${problem_list}       | Top level syntax.                                                                                                |
| [ok-syntax](#check_process_ok-syntax)         | %(status): all processes are ok. | ok syntax.                                                                                                       |
| [empty-syntax](#check_process_empty-syntax)   | %(status): No processes found    | Empty syntax.                                                                                                    |
| [detail-syntax](#check_process_detail-syntax) | ${exe}=${state}                  | Detail level syntax.                                                                                             |
| [perf-syntax](#check_process_perf-syntax)     | ${exe}                           | Performance alias syntax.                                                                                        |
| process                                       |                                  | The service to check, set this to * to check all services                                                        |
| scan-info                                     |                                  | If all process metrics should be fetched (otherwise only status is fetched)                                      |
| scan-16bit                                    |                                  | If 16bit processes should be included                                                                            |
| [delta](#check_process_delta)                 |                                  | Calculate delta over one elapsed second.                                                                         |
| scan-unreadable                               |                                  | If unreadable processes should be included (will not have information)                                           |
| total                                         | N/A                              | Include the total of all matching files                                                                          |



<a name="check_process_filter"/>
**filter:**

Filter which marks interesting items.
Interesting items are items which will be included in the check.
They do not denote warning or critical state instead it defines which items are relevant and you can remove unwanted items.


*Deafult Value:* | `state != 'unreadable'`



<a name="check_process_warning"/>
**warning:**

Filter which marks items which generates a warning state.
If anything matches this filter the return status will be escalated to warning.



*Deafult Value:* | `state not in ('started')`



<a name="check_process_critical"/>
**critical:**

Filter which marks items which generates a critical state.
If anything matches this filter the return status will be escalated to critical.



*Deafult Value:* | `state = 'stopped', count = 0`



<a name="check_process_ok"/>
**ok:**

Filter which marks items which generates an ok state.
If anything matches this any previous state for this item will be reset to ok.






<a name="check_process_empty-state"/>
**empty-state:**

Return status to use when nothing matched filter.
If no filter is specified this will never happen unless the file is empty.


*Deafult Value:* | `unknown`



<a name="check_process_perf-config"/>
**perf-config:**

Performance data generation configuration
TODO: obj ( key: value; key: value) obj (key:valuer;key:value)





<a name="check_process_top-syntax"/>
**top-syntax:**

Top level syntax.
Used to format the message to return can include text as well as special keywords which will include information from the checks.
To add a keyword to the message you can use two syntaxes either ${keyword} or %(keyword) (there is no difference between them apart from ${} can be difficult to excpae on linux).


*Deafult Value:* | `${status}: ${problem_list}`



<a name="check_process_ok-syntax"/>
**ok-syntax:**

ok syntax.
DEPRECATED! This is the syntax for when an ok result is returned.
This value will not be used if your syntax contains %(list) or %(count).


*Deafult Value:* | `%(status): all processes are ok.`



<a name="check_process_empty-syntax"/>
**empty-syntax:**

Empty syntax.
DEPRECATED! This is the syntax for when nothing matches the filter.


*Deafult Value:* | `%(status): No processes found`



<a name="check_process_detail-syntax"/>
**detail-syntax:**

Detail level syntax.
Used to format each resulting item in the message.
%(list) will be replaced with all the items formated by this syntax string in the top-syntax.
To add a keyword to the message you can use two syntaxes either ${keyword} or %(keyword) (there is no difference between them apart from ${} can be difficult to excpae on linux).


*Deafult Value:* | `${exe}=${state}`



<a name="check_process_perf-syntax"/>
**perf-syntax:**

Performance alias syntax.
This is the syntax for the base names of the performance data.


*Deafult Value:* | `${exe}`



<a name="check_process_delta"/>
**delta:**

Calculate delta over one elapsed second.
This call will measure values and then sleep for 2 second and then measure again calculating deltas.






<a name="check_process_filter_keys"/>
#### Filter keywords


| Option                                              | Description                                                                                                  |
|-----------------------------------------------------|--------------------------------------------------------------------------------------------------------------|
| [command_line](#check_process_command_line)         | Command line of process (not always available)                                                               |
| [count](#check_process_count)                       | Number of items matching the filter. Common option for all checks.                                           |
| [creation](#check_process_creation)                 | Creation time                                                                                                |
| [crit_count](#check_process_crit_count)             | Number of items matched the critical criteria. Common option for all checks.                                 |
| [crit_list](#check_process_crit_list)               | A list of all items which matched the critical criteria. Common option for all checks.                       |
| [detail_list](#check_process_detail_list)           | A special list with critical, then warning and finally ok. Common option for all checks.                     |
| [error](#check_process_error)                       | Any error messages associated with fetching info                                                             |
| [exe](#check_process_exe)                           | The name of the executable                                                                                   |
| [filename](#check_process_filename)                 | Name of process (with path)                                                                                  |
| [gdi_handles](#check_process_gdi_handles)           | Number of handles                                                                                            |
| [handles](#check_process_handles)                   | Number of handles                                                                                            |
| [hung](#check_process_hung)                         | Process is hung                                                                                              |
| [kernel](#check_process_kernel)                     | Kernel time in seconds                                                                                       |
| [legacy_state](#check_process_legacy_state)         | Get process status (for legacy use via check_nt only)                                                        |
| [list](#check_process_list)                         | A list of all items which matched the filter. Common option for all checks.                                  |
| [new](#check_process_new)                           | Process is new (can inly be used for real-time filters)                                                      |
| [ok_count](#check_process_ok_count)                 | Number of items matched the ok criteria. Common option for all checks.                                       |
| [ok_list](#check_process_ok_list)                   | A list of all items which matched the ok criteria. Common option for all checks.                             |
| [page_fault](#check_process_page_fault)             | Page fault count                                                                                             |
| [pagefile](#check_process_pagefile)                 | Peak page file use in bytes                                                                                  |
| [peak_pagefile](#check_process_peak_pagefile)       | Page file usage in bytes                                                                                     |
| [peak_virtual](#check_process_peak_virtual)         | Peak virtual size in bytes                                                                                   |
| [peak_working_set](#check_process_peak_working_set) | Peak working set in bytes                                                                                    |
| [pid](#check_process_pid)                           | Process id                                                                                                   |
| [problem_count](#check_process_problem_count)       | Number of items matched either warning or critical criteria. Common option for all checks.                   |
| [problem_list](#check_process_problem_list)         | A list of all items which matched either the critical or the warning criteria. Common option for all checks. |
| [started](#check_process_started)                   | Process is started                                                                                           |
| [state](#check_process_state)                       | The current state (started, stopped hung)                                                                    |
| [status](#check_process_status)                     | The returned status (OK/WARN/CRIT/UNKNOWN). Common option for all checks.                                    |
| [stopped](#check_process_stopped)                   | Process is stopped                                                                                           |
| [time](#check_process_time)                         | User-kernel time in seconds                                                                                  |
| [total](#check_process_total)                       | Total number of items. Common option for all checks.                                                         |
| [user](#check_process_user)                         | User time in seconds                                                                                         |
| [user_handles](#check_process_user_handles)         | Number of handles                                                                                            |
| [virtual](#check_process_virtual)                   | Virtual size in bytes                                                                                        |
| [warn_count](#check_process_warn_count)             | Number of items matched the warning criteria. Common option for all checks.                                  |
| [warn_list](#check_process_warn_list)               | A list of all items which matched the warning criteria. Common option for all checks.                        |
| [working_set](#check_process_working_set)           | Working set in bytes                                                                                         |


### check_service

Check the state of one or more of the computer services.

* [Samples](#check_service_samples)

* [Command-line Arguments](#check_service_options)
* [Filter keywords](#check_service_filter_keys)


<a name="check_service_samples"/>
#### Sample Commands

_To edit these sample please edit [this page](https://github.com/mickem/nscp-docs/blob/master/samples/CheckSystem_check_service_samples.md)_

**Default check:**

```
check_service
OK all services are ok.
```

**Excluding services using exclude**::

```
check_service "exclude=clr_optimization_v4.0.30319_32"  "exclude=clr_optimization_v4.0.30319_64"
WARNING: gupdate=stopped (auto), Net Driver HPZ12=stopped (auto), NSClientpp=stopped (auto), nscp=stopped (auto), Pml Driver HPZ12=stopped (auto), SkypeUpdate=stopped (auto), sppsvc=stopped (auto)
```

**Show all service by changing the syntax**::

```
check_service "top-syntax=${list}" "detail-syntax=${name}:${state}"
AdobeActiveFileMonitor10.0:running, AdobeARMservice:running, AdobeFlashPlayerUpdateSvc:stopped, ..., WwanSvc:stopped
```

**Excluding services using the filter**::

```
check_service "filter=start_type = 'auto' and name not in ('Bonjour Service', 'Net Driver HPZ12')"
AdobeActiveFileMonitor10.0: running, AdobeARMservice: running, AMD External Events Utility: running,  ... wuauserv: running
```

**Exclude versus filter**::

You can use both exclude and filter to exclude services the befnefit of exclude is that it is faster with the obvious drawback that it only works on the service name.
The upside to filters are that they are richer in terms of functionality i.e. substring matching (as below).

Regular check
```
check_service
L        cli CRITICAL: CRITICAL: nfoo=stopped (auto), nscp=stopped (auto), nscp2=stopped (auto), ...
```

Excluding nfoo service with exclude:
```
check_service exclude=nfoo
L        cli CRITICAL: CRITICAL: nscp=stopped (auto), nscp2=stopped (auto), ...
```

Excluding nscp2 with substring like mathcing filter:
```
check_service exclude=nfoo "filter=name not like 'nscp'"
L        cli CRITICAL: CRITICAL: ...
```


Default check **via NRPE**::

```
check_nrpe --host 192.168.56.103 --command check_service
WARNING: DPS=stopped (auto), MSDTC=stopped (auto), sppsvc=stopped (auto), UALSVC=stopped (auto)
```

**Check that a service is not started**::

```
check_service service=nscp "crit=state = 'started'" warn=none
```



<a name="check_service_warn"/>

<a name="check_service_crit"/>

<a name="check_service_debug"/>

<a name="check_service_show-all"/>

<a name="check_service_escape-html"/>

<a name="check_service_help"/>

<a name="check_service_help-pb"/>

<a name="check_service_show-default"/>

<a name="check_service_help-short"/>

<a name="check_service_computer"/>

<a name="check_service_service"/>

<a name="check_service_exclude"/>

<a name="check_service_only-essential"/>

<a name="check_service_only-ignored"/>

<a name="check_service_only-role"/>

<a name="check_service_only-supporting"/>

<a name="check_service_only-system"/>

<a name="check_service_only-user"/>

<a name="check_service_options"/>
#### Command-line Arguments


| Option                                        | Default Value                                   | Description                                                                                                                                           |
|-----------------------------------------------|-------------------------------------------------|-------------------------------------------------------------------------------------------------------------------------------------------------------|
| [filter](#check_service_filter)               |                                                 | Filter which marks interesting items.                                                                                                                 |
| [warning](#check_service_warning)             | not state_is_perfect()                          | Filter which marks items which generates a warning state.                                                                                             |
| warn                                          |                                                 | Short alias for warning                                                                                                                               |
| [critical](#check_service_critical)           | not state_is_ok()                               | Filter which marks items which generates a critical state.                                                                                            |
| crit                                          |                                                 | Short alias for critical.                                                                                                                             |
| [ok](#check_service_ok)                       |                                                 | Filter which marks items which generates an ok state.                                                                                                 |
| debug                                         | N/A                                             | Show debugging information in the log                                                                                                                 |
| show-all                                      | N/A                                             | Show details for all matches regardless of status (normally details are only showed for warnings and criticals).                                      |
| [empty-state](#check_service_empty-state)     | unknown                                         | Return status to use when nothing matched filter.                                                                                                     |
| [perf-config](#check_service_perf-config)     |                                                 | Performance data generation configuration                                                                                                             |
| escape-html                                   | N/A                                             | Escape any < and > characters to prevent HTML encoding                                                                                                |
| help                                          | N/A                                             | Show help screen (this screen)                                                                                                                        |
| help-pb                                       | N/A                                             | Show help screen as a protocol buffer payload                                                                                                         |
| show-default                                  | N/A                                             | Show default values for a given command                                                                                                               |
| help-short                                    | N/A                                             | Show help screen (short format).                                                                                                                      |
| [top-syntax](#check_service_top-syntax)       | ${status}: ${crit_list}, delayed (${warn_list}) | Top level syntax.                                                                                                                                     |
| [ok-syntax](#check_service_ok-syntax)         | %(status): All %(count) service(s) are ok.      | ok syntax.                                                                                                                                            |
| [empty-syntax](#check_service_empty-syntax)   | %(status): No services found                    | Empty syntax.                                                                                                                                         |
| [detail-syntax](#check_service_detail-syntax) | ${name}=${state} (${start_type})                | Detail level syntax.                                                                                                                                  |
| [perf-syntax](#check_service_perf-syntax)     | ${name}                                         | Performance alias syntax.                                                                                                                             |
| computer                                      |                                                 | The name of the remote computer to check                                                                                                              |
| service                                       |                                                 | The service to check, set this to * to check all services                                                                                             |
| exclude                                       |                                                 | A list of services to ignore (mainly usefull in combination with service=*)                                                                           |
| [type](#check_service_type)                   | service                                         | The types of services to enumerate available types are driver, file-system-driver, kernel-driver, service, service-own-process, service-share-process |
| [state](#check_service_state)                 | all                                             | The types of services to enumerate available states are active, inactive or all                                                                       |
| only-essential                                | N/A                                             | Set filter to classification = 'essential'                                                                                                            |
| only-ignored                                  | N/A                                             | Set filter to classification = 'ignored'                                                                                                              |
| only-role                                     | N/A                                             | Set filter to classification = 'role'                                                                                                                 |
| only-supporting                               | N/A                                             | Set filter to classification = 'supporting'                                                                                                           |
| only-system                                   | N/A                                             | Set filter to classification = 'system'                                                                                                               |
| only-user                                     | N/A                                             | Set filter to classification = 'user'                                                                                                                 |



<a name="check_service_filter"/>
**filter:**

Filter which marks interesting items.
Interesting items are items which will be included in the check.
They do not denote warning or critical state instead it defines which items are relevant and you can remove unwanted items.





<a name="check_service_warning"/>
**warning:**

Filter which marks items which generates a warning state.
If anything matches this filter the return status will be escalated to warning.



*Deafult Value:* | `not state_is_perfect()`



<a name="check_service_critical"/>
**critical:**

Filter which marks items which generates a critical state.
If anything matches this filter the return status will be escalated to critical.



*Deafult Value:* | `not state_is_ok()`



<a name="check_service_ok"/>
**ok:**

Filter which marks items which generates an ok state.
If anything matches this any previous state for this item will be reset to ok.






<a name="check_service_empty-state"/>
**empty-state:**

Return status to use when nothing matched filter.
If no filter is specified this will never happen unless the file is empty.


*Deafult Value:* | `unknown`



<a name="check_service_perf-config"/>
**perf-config:**

Performance data generation configuration
TODO: obj ( key: value; key: value) obj (key:valuer;key:value)





<a name="check_service_top-syntax"/>
**top-syntax:**

Top level syntax.
Used to format the message to return can include text as well as special keywords which will include information from the checks.
To add a keyword to the message you can use two syntaxes either ${keyword} or %(keyword) (there is no difference between them apart from ${} can be difficult to excpae on linux).


*Deafult Value:* | `${status}: ${crit_list}, delayed (${warn_list})`



<a name="check_service_ok-syntax"/>
**ok-syntax:**

ok syntax.
DEPRECATED! This is the syntax for when an ok result is returned.
This value will not be used if your syntax contains %(list) or %(count).


*Deafult Value:* | `%(status): All %(count) service(s) are ok.`



<a name="check_service_empty-syntax"/>
**empty-syntax:**

Empty syntax.
DEPRECATED! This is the syntax for when nothing matches the filter.


*Deafult Value:* | `%(status): No services found`



<a name="check_service_detail-syntax"/>
**detail-syntax:**

Detail level syntax.
Used to format each resulting item in the message.
%(list) will be replaced with all the items formated by this syntax string in the top-syntax.
To add a keyword to the message you can use two syntaxes either ${keyword} or %(keyword) (there is no difference between them apart from ${} can be difficult to excpae on linux).


*Deafult Value:* | `${name}=${state} (${start_type})`



<a name="check_service_perf-syntax"/>
**perf-syntax:**

Performance alias syntax.
This is the syntax for the base names of the performance data.


*Deafult Value:* | `${name}`



<a name="check_service_type"/>
**type:**

The types of services to enumerate available types are driver, file-system-driver, kernel-driver, service, service-own-process, service-share-process


*Deafult Value:* | `service`



<a name="check_service_state"/>
**state:**

The types of services to enumerate available states are active, inactive or all


*Deafult Value:* | `all`




<a name="check_service_filter_keys"/>
#### Filter keywords


| Option                                                  | Description                                                                                                  |
|---------------------------------------------------------|--------------------------------------------------------------------------------------------------------------|
| [classification](#check_service_classification)         | Get classification                                                                                           |
| [count](#check_service_count)                           | Number of items matching the filter. Common option for all checks.                                           |
| [crit_count](#check_service_crit_count)                 | Number of items matched the critical criteria. Common option for all checks.                                 |
| [crit_list](#check_service_crit_list)                   | A list of all items which matched the critical criteria. Common option for all checks.                       |
| [delayed](#check_service_delayed)                       | If the service is delayed                                                                                    |
| [desc](#check_service_desc)                             | Service description                                                                                          |
| [detail_list](#check_service_detail_list)               | A special list with critical, then warning and finally ok. Common option for all checks.                     |
| [is_trigger](#check_service_is_trigger)                 | If the service is has associated triggers                                                                    |
| [legacy_state](#check_service_legacy_state)             | Get legacy state (deprecated and only used by check_nt)                                                      |
| [list](#check_service_list)                             | A list of all items which matched the filter. Common option for all checks.                                  |
| [name](#check_service_name)                             | Service name                                                                                                 |
| [ok_count](#check_service_ok_count)                     | Number of items matched the ok criteria. Common option for all checks.                                       |
| [ok_list](#check_service_ok_list)                       | A list of all items which matched the ok criteria. Common option for all checks.                             |
| [pid](#check_service_pid)                               | Process id                                                                                                   |
| [problem_count](#check_service_problem_count)           | Number of items matched either warning or critical criteria. Common option for all checks.                   |
| [problem_list](#check_service_problem_list)             | A list of all items which matched either the critical or the warning criteria. Common option for all checks. |
| [start_type](#check_service_start_type)                 | The configured start type ()                                                                                 |
| [state](#check_service_state)                           | The current state ()                                                                                         |
| [state_is_ok()](#check_service_state_is_ok())           | Check if the state is ok, i.e. all running services are runningelayed services are allowed to be stopped)    |
| [state_is_perfect()](#check_service_state_is_perfect()) | Check if the state is ok, i.e. all running services are running                                              |
| [status](#check_service_status)                         | The returned status (OK/WARN/CRIT/UNKNOWN). Common option for all checks.                                    |
| [total](#check_service_total)                           | Total number of items. Common option for all checks.                                                         |
| [triggers](#check_service_triggers)                     | The number of associated triggers for this service                                                           |
| [warn_count](#check_service_warn_count)                 | Number of items matched the warning criteria. Common option for all checks.                                  |
| [warn_list](#check_service_warn_list)                   | A list of all items which matched the warning criteria. Common option for all checks.                        |


### check_uptime

Check time since last server re-boot.

* [Samples](#check_uptime_samples)

* [Command-line Arguments](#check_uptime_options)
* [Filter keywords](#check_uptime_filter_keys)


<a name="check_uptime_samples"/>
#### Sample Commands

_To edit these sample please edit [this page](https://github.com/mickem/nscp-docs/blob/master/samples/CheckSystem_check_uptime_samples.md)_

**Default check:**

```
check_uptime
uptime: -9:02, boot: 2013-aug-18 08:29:13
'uptime uptime'=1376814553s;1376760683;1376803883
```

Adding **warning and critical thresholds**::

```
check_uptime "warn=uptime < -2d" "crit=uptime < -1d"
...
```

Default check **via NRPE**::

```
check_nrpe --host 192.168.56.103 --command check_uptime
uptime: -0:3, boot: 2013-sep-08 18:41:06 (UCT)|'uptime'=1378665666;1378579481;1378622681
```




<a name="check_uptime_warn"/>

<a name="check_uptime_crit"/>

<a name="check_uptime_debug"/>

<a name="check_uptime_show-all"/>

<a name="check_uptime_escape-html"/>

<a name="check_uptime_help"/>

<a name="check_uptime_help-pb"/>

<a name="check_uptime_show-default"/>

<a name="check_uptime_help-short"/>

<a name="check_uptime_options"/>
#### Command-line Arguments


| Option                                       | Default Value                           | Description                                                                                                      |
|----------------------------------------------|-----------------------------------------|------------------------------------------------------------------------------------------------------------------|
| [filter](#check_uptime_filter)               |                                         | Filter which marks interesting items.                                                                            |
| [warning](#check_uptime_warning)             | uptime < 2d                             | Filter which marks items which generates a warning state.                                                        |
| warn                                         |                                         | Short alias for warning                                                                                          |
| [critical](#check_uptime_critical)           | uptime < 1d                             | Filter which marks items which generates a critical state.                                                       |
| crit                                         |                                         | Short alias for critical.                                                                                        |
| [ok](#check_uptime_ok)                       |                                         | Filter which marks items which generates an ok state.                                                            |
| debug                                        | N/A                                     | Show debugging information in the log                                                                            |
| show-all                                     | N/A                                     | Show details for all matches regardless of status (normally details are only showed for warnings and criticals). |
| [empty-state](#check_uptime_empty-state)     | ignored                                 | Return status to use when nothing matched filter.                                                                |
| [perf-config](#check_uptime_perf-config)     |                                         | Performance data generation configuration                                                                        |
| escape-html                                  | N/A                                     | Escape any < and > characters to prevent HTML encoding                                                           |
| help                                         | N/A                                     | Show help screen (this screen)                                                                                   |
| help-pb                                      | N/A                                     | Show help screen as a protocol buffer payload                                                                    |
| show-default                                 | N/A                                     | Show default values for a given command                                                                          |
| help-short                                   | N/A                                     | Show help screen (short format).                                                                                 |
| [top-syntax](#check_uptime_top-syntax)       | ${status}: ${list}                      | Top level syntax.                                                                                                |
| [ok-syntax](#check_uptime_ok-syntax)         |                                         | ok syntax.                                                                                                       |
| [empty-syntax](#check_uptime_empty-syntax)   |                                         | Empty syntax.                                                                                                    |
| [detail-syntax](#check_uptime_detail-syntax) | uptime: ${uptime}h, boot: ${boot} (UTC) | Detail level syntax.                                                                                             |
| [perf-syntax](#check_uptime_perf-syntax)     | uptime                                  | Performance alias syntax.                                                                                        |



<a name="check_uptime_filter"/>
**filter:**

Filter which marks interesting items.
Interesting items are items which will be included in the check.
They do not denote warning or critical state instead it defines which items are relevant and you can remove unwanted items.





<a name="check_uptime_warning"/>
**warning:**

Filter which marks items which generates a warning state.
If anything matches this filter the return status will be escalated to warning.



*Deafult Value:* | `uptime < 2d`



<a name="check_uptime_critical"/>
**critical:**

Filter which marks items which generates a critical state.
If anything matches this filter the return status will be escalated to critical.



*Deafult Value:* | `uptime < 1d`



<a name="check_uptime_ok"/>
**ok:**

Filter which marks items which generates an ok state.
If anything matches this any previous state for this item will be reset to ok.






<a name="check_uptime_empty-state"/>
**empty-state:**

Return status to use when nothing matched filter.
If no filter is specified this will never happen unless the file is empty.


*Deafult Value:* | `ignored`



<a name="check_uptime_perf-config"/>
**perf-config:**

Performance data generation configuration
TODO: obj ( key: value; key: value) obj (key:valuer;key:value)





<a name="check_uptime_top-syntax"/>
**top-syntax:**

Top level syntax.
Used to format the message to return can include text as well as special keywords which will include information from the checks.
To add a keyword to the message you can use two syntaxes either ${keyword} or %(keyword) (there is no difference between them apart from ${} can be difficult to excpae on linux).


*Deafult Value:* | `${status}: ${list}`



<a name="check_uptime_ok-syntax"/>
**ok-syntax:**

ok syntax.
DEPRECATED! This is the syntax for when an ok result is returned.
This value will not be used if your syntax contains %(list) or %(count).





<a name="check_uptime_empty-syntax"/>
**empty-syntax:**

Empty syntax.
DEPRECATED! This is the syntax for when nothing matches the filter.





<a name="check_uptime_detail-syntax"/>
**detail-syntax:**

Detail level syntax.
Used to format each resulting item in the message.
%(list) will be replaced with all the items formated by this syntax string in the top-syntax.
To add a keyword to the message you can use two syntaxes either ${keyword} or %(keyword) (there is no difference between them apart from ${} can be difficult to excpae on linux).


*Deafult Value:* | `uptime: ${uptime}h, boot: ${boot} (UTC)`



<a name="check_uptime_perf-syntax"/>
**perf-syntax:**

Performance alias syntax.
This is the syntax for the base names of the performance data.


*Deafult Value:* | `uptime`




<a name="check_uptime_filter_keys"/>
#### Filter keywords


| Option                                       | Description                                                                                                  |
|----------------------------------------------|--------------------------------------------------------------------------------------------------------------|
| [boot](#check_uptime_boot)                   | System boot time                                                                                             |
| [count](#check_uptime_count)                 | Number of items matching the filter. Common option for all checks.                                           |
| [crit_count](#check_uptime_crit_count)       | Number of items matched the critical criteria. Common option for all checks.                                 |
| [crit_list](#check_uptime_crit_list)         | A list of all items which matched the critical criteria. Common option for all checks.                       |
| [detail_list](#check_uptime_detail_list)     | A special list with critical, then warning and finally ok. Common option for all checks.                     |
| [list](#check_uptime_list)                   | A list of all items which matched the filter. Common option for all checks.                                  |
| [ok_count](#check_uptime_ok_count)           | Number of items matched the ok criteria. Common option for all checks.                                       |
| [ok_list](#check_uptime_ok_list)             | A list of all items which matched the ok criteria. Common option for all checks.                             |
| [problem_count](#check_uptime_problem_count) | Number of items matched either warning or critical criteria. Common option for all checks.                   |
| [problem_list](#check_uptime_problem_list)   | A list of all items which matched either the critical or the warning criteria. Common option for all checks. |
| [status](#check_uptime_status)               | The returned status (OK/WARN/CRIT/UNKNOWN). Common option for all checks.                                    |
| [total](#check_uptime_total)                 | Total number of items. Common option for all checks.                                                         |
| [uptime](#check_uptime_uptime)               | Time since last boot                                                                                         |
| [warn_count](#check_uptime_warn_count)       | Number of items matched the warning criteria. Common option for all checks.                                  |
| [warn_list](#check_uptime_warn_list)         | A list of all items which matched the warning criteria. Common option for all checks.                        |


### checkcounter

Legacy version of check_pdh


* [Command-line Arguments](#checkcounter_options)





<a name="checkcounter_help"/>

<a name="checkcounter_help-pb"/>

<a name="checkcounter_show-default"/>

<a name="checkcounter_help-short"/>

<a name="checkcounter_Counter"/>

<a name="checkcounter_MaxWarn"/>

<a name="checkcounter_MaxCrit"/>

<a name="checkcounter_MinWarn"/>

<a name="checkcounter_MinCrit"/>

<a name="checkcounter_options"/>
#### Command-line Arguments


| Option                           | Default Value | Description                                                                                           |
|----------------------------------|---------------|-------------------------------------------------------------------------------------------------------|
| help                             | N/A           | Show help screen (this screen)                                                                        |
| help-pb                          | N/A           | Show help screen as a protocol buffer payload                                                         |
| show-default                     | N/A           | Show default values for a given command                                                               |
| help-short                       | N/A           | Show help screen (short format).                                                                      |
| Counter                          |               | The time to check                                                                                     |
| [ShowAll](#checkcounter_ShowAll) | short         | Configures display format (if set shows all items not only failures, if set to long shows all cores). |
| MaxWarn                          |               | Maximum value before a warning is returned.                                                           |
| MaxCrit                          |               | Maximum value before a critical is returned.                                                          |
| MinWarn                          |               | Minimum value before a warning is returned.                                                           |
| MinCrit                          |               | Minimum value before a critical is returned.                                                          |



<a name="checkcounter_ShowAll"/>
**ShowAll:**

Configures display format (if set shows all items not only failures, if set to long shows all cores).


*Deafult Value:* | `short`




### checkcpu

Legacy version of check_cpu


* [Command-line Arguments](#checkcpu_options)





<a name="checkcpu_help"/>

<a name="checkcpu_help-pb"/>

<a name="checkcpu_show-default"/>

<a name="checkcpu_help-short"/>

<a name="checkcpu_time"/>

<a name="checkcpu_MaxWarn"/>

<a name="checkcpu_MaxCrit"/>

<a name="checkcpu_MinWarn"/>

<a name="checkcpu_MinCrit"/>

<a name="checkcpu_warn"/>

<a name="checkcpu_crit"/>

<a name="checkcpu_options"/>
#### Command-line Arguments


| Option                       | Default Value | Description                                                                                           |
|------------------------------|---------------|-------------------------------------------------------------------------------------------------------|
| help                         | N/A           | Show help screen (this screen)                                                                        |
| help-pb                      | N/A           | Show help screen as a protocol buffer payload                                                         |
| show-default                 | N/A           | Show default values for a given command                                                               |
| help-short                   | N/A           | Show help screen (short format).                                                                      |
| time                         |               | The time to check                                                                                     |
| [ShowAll](#checkcpu_ShowAll) | short         | Configures display format (if set shows all items not only failures, if set to long shows all cores). |
| MaxWarn                      |               | Maximum value before a warning is returned.                                                           |
| MaxCrit                      |               | Maximum value before a critical is returned.                                                          |
| MinWarn                      |               | Minimum value before a warning is returned.                                                           |
| MinCrit                      |               | Minimum value before a critical is returned.                                                          |
| warn                         |               | Maximum value before a warning is returned.                                                           |
| crit                         |               | Maximum value before a critical is returned.                                                          |



<a name="checkcpu_ShowAll"/>
**ShowAll:**

Configures display format (if set shows all items not only failures, if set to long shows all cores).


*Deafult Value:* | `short`




### checkmem

Legacy version of check_mem


* [Command-line Arguments](#checkmem_options)





<a name="checkmem_help"/>

<a name="checkmem_help-pb"/>

<a name="checkmem_show-default"/>

<a name="checkmem_help-short"/>

<a name="checkmem_type"/>

<a name="checkmem_MaxWarn"/>

<a name="checkmem_MaxCrit"/>

<a name="checkmem_MinWarn"/>

<a name="checkmem_MinCrit"/>

<a name="checkmem_warn"/>

<a name="checkmem_crit"/>

<a name="checkmem_options"/>
#### Command-line Arguments


| Option                       | Default Value | Description                                                                                           |
|------------------------------|---------------|-------------------------------------------------------------------------------------------------------|
| help                         | N/A           | Show help screen (this screen)                                                                        |
| help-pb                      | N/A           | Show help screen as a protocol buffer payload                                                         |
| show-default                 | N/A           | Show default values for a given command                                                               |
| help-short                   | N/A           | Show help screen (short format).                                                                      |
| type                         |               | The types to check                                                                                    |
| [ShowAll](#checkmem_ShowAll) | short         | Configures display format (if set shows all items not only failures, if set to long shows all cores). |
| MaxWarn                      |               | Maximum value before a warning is returned.                                                           |
| MaxCrit                      |               | Maximum value before a critical is returned.                                                          |
| MinWarn                      |               | Minimum value before a warning is returned.                                                           |
| MinCrit                      |               | Minimum value before a critical is returned.                                                          |
| warn                         |               | Maximum value before a warning is returned.                                                           |
| crit                         |               | Maximum value before a critical is returned.                                                          |



<a name="checkmem_ShowAll"/>
**ShowAll:**

Configures display format (if set shows all items not only failures, if set to long shows all cores).


*Deafult Value:* | `short`




### checkprocstate

Legacy version of check_process


* [Command-line Arguments](#checkprocstate_options)





<a name="checkprocstate_help"/>

<a name="checkprocstate_help-pb"/>

<a name="checkprocstate_show-default"/>

<a name="checkprocstate_help-short"/>

<a name="checkprocstate_MaxWarnCount"/>

<a name="checkprocstate_MaxCritCount"/>

<a name="checkprocstate_MinWarnCount"/>

<a name="checkprocstate_MinCritCount"/>

<a name="checkprocstate_options"/>
#### Command-line Arguments


| Option                             | Default Value | Description                                                                                           |
|------------------------------------|---------------|-------------------------------------------------------------------------------------------------------|
| help                               | N/A           | Show help screen (this screen)                                                                        |
| help-pb                            | N/A           | Show help screen as a protocol buffer payload                                                         |
| show-default                       | N/A           | Show default values for a given command                                                               |
| help-short                         | N/A           | Show help screen (short format).                                                                      |
| [ShowAll](#checkprocstate_ShowAll) | short         | Configures display format (if set shows all items not only failures, if set to long shows all cores). |
| MaxWarnCount                       |               | Maximum value before a warning is returned.                                                           |
| MaxCritCount                       |               | Maximum value before a critical is returned.                                                          |
| MinWarnCount                       |               | Minimum value before a warning is returned.                                                           |
| MinCritCount                       |               | Minimum value before a critical is returned.                                                          |



<a name="checkprocstate_ShowAll"/>
**ShowAll:**

Configures display format (if set shows all items not only failures, if set to long shows all cores).


*Deafult Value:* | `short`




### checkservicestate

Legacy version of check_service


* [Command-line Arguments](#checkservicestate_options)





<a name="checkservicestate_help"/>

<a name="checkservicestate_help-pb"/>

<a name="checkservicestate_show-default"/>

<a name="checkservicestate_help-short"/>

<a name="checkservicestate_exclude"/>

<a name="checkservicestate_options"/>
#### Command-line Arguments


| Option                                  | Default Value | Description                                                                                           |
|-----------------------------------------|---------------|-------------------------------------------------------------------------------------------------------|
| help                                    | N/A           | Show help screen (this screen)                                                                        |
| help-pb                                 | N/A           | Show help screen as a protocol buffer payload                                                         |
| show-default                            | N/A           | Show default values for a given command                                                               |
| help-short                              | N/A           | Show help screen (short format).                                                                      |
| [CheckAll](#checkservicestate_CheckAll) | true          | Check all services.                                                                                   |
| exclude                                 |               | Exclude services                                                                                      |
| [ShowAll](#checkservicestate_ShowAll)   | short         | Configures display format (if set shows all items not only failures, if set to long shows all cores). |



<a name="checkservicestate_CheckAll"/>
**CheckAll:**

Check all services.


*Deafult Value:* | `true`



<a name="checkservicestate_ShowAll"/>
**ShowAll:**

Configures display format (if set shows all items not only failures, if set to long shows all cores).


*Deafult Value:* | `short`




### checkuptime

Legacy version of check_uptime


* [Command-line Arguments](#checkuptime_options)





<a name="checkuptime_help"/>

<a name="checkuptime_help-pb"/>

<a name="checkuptime_show-default"/>

<a name="checkuptime_help-short"/>

<a name="checkuptime_MaxWarn"/>

<a name="checkuptime_MaxCrit"/>

<a name="checkuptime_MinWarn"/>

<a name="checkuptime_MinCrit"/>

<a name="checkuptime_warn"/>

<a name="checkuptime_crit"/>

<a name="checkuptime_options"/>
#### Command-line Arguments


| Option                          | Default Value | Description                                                                                           |
|---------------------------------|---------------|-------------------------------------------------------------------------------------------------------|
| help                            | N/A           | Show help screen (this screen)                                                                        |
| help-pb                         | N/A           | Show help screen as a protocol buffer payload                                                         |
| show-default                    | N/A           | Show default values for a given command                                                               |
| help-short                      | N/A           | Show help screen (short format).                                                                      |
| [ShowAll](#checkuptime_ShowAll) | short         | Configures display format (if set shows all items not only failures, if set to long shows all cores). |
| MaxWarn                         |               | Maximum value before a warning is returned.                                                           |
| MaxCrit                         |               | Maximum value before a critical is returned.                                                          |
| MinWarn                         |               | Minimum value before a warning is returned.                                                           |
| MinCrit                         |               | Minimum value before a critical is returned.                                                          |
| warn                            |               | Maximum value before a warning is returned.                                                           |
| crit                            |               | Maximum value before a critical is returned.                                                          |



<a name="checkuptime_ShowAll"/>
**ShowAll:**

Configures display format (if set shows all items not only failures, if set to long shows all cores).


*Deafult Value:* | `short`






## Configuration

<a name="/settings/system/windows"/>
### Windows system

Section for system checks and system settings




| Key                                                                      | Default Value | Description              |
|--------------------------------------------------------------------------|---------------|--------------------------|
| [default buffer length](#/settings/system/windows_default buffer length) | 1h            | Default buffer time      |
| [disable](#/settings/system/windows_disable)                             |               | Disable automatic checks |
| [subsystem](#/settings/system/windows_subsystem)                         | default       | PDH subsystem            |



```ini
# Section for system checks and system settings
[/settings/system/windows]
default buffer length=1h
subsystem=default

```




<a name="/settings/system/windows_default buffer length"/>

**Default buffer time**

Used to define the default size of range buffer checks (ie. CPU).





| Key            | Description                                           |
|----------------|-------------------------------------------------------|
| Path:          | [/settings/system/windows](#/settings/system/windows) |
| Key:           | default buffer length                                 |
| Default value: | `1h`                                                  |
| Used by:       | CheckSystem                                           |


**Sample:**

```
[/settings/system/windows]
# Default buffer time
default buffer length=1h
```


<a name="/settings/system/windows_disable"/>

**Disable automatic checks**

A comma separated list of checks to disable in the collector: cpu,handles,network,metrics,pdh. Please note disabling these will mean part of NSClient++ will no longer function as expected.






| Key            | Description                                           |
|----------------|-------------------------------------------------------|
| Path:          | [/settings/system/windows](#/settings/system/windows) |
| Key:           | disable                                               |
| Advanced:      | Yes (means it is not commonly used)                   |
| Default value: | _N/A_                                                 |
| Used by:       | CheckSystem                                           |


**Sample:**

```
[/settings/system/windows]
# Disable automatic checks
disable=
```


<a name="/settings/system/windows_subsystem"/>

**PDH subsystem**

Set which pdh subsystem to use.
Currently default and thread-safe are supported where thread-safe is slower but required if you have some problematic counters.





| Key            | Description                                           |
|----------------|-------------------------------------------------------|
| Path:          | [/settings/system/windows](#/settings/system/windows) |
| Key:           | subsystem                                             |
| Advanced:      | Yes (means it is not commonly used)                   |
| Default value: | `default`                                             |
| Used by:       | CheckSystem                                           |


**Sample:**

```
[/settings/system/windows]
# PDH subsystem
subsystem=default
```


<a name="/settings/system/windows/counters"/>
### PDH Counters

Add counters to check


This is a section of objects. This means that you will create objects below this point by adding sections which all look the same.


**Keys:**


| Key                 | Default Value | Description         |
|---------------------|---------------|---------------------|
| alias               |               | ALIAS               |
| buffer size         |               | BUFFER SIZE         |
| collection strategy |               | COLLECTION STRATEGY |
| counter             |               | COUNTER             |
| flags               |               | FLAGS               |
| instances           |               | Interpret instances |
| is template         | false         | IS TEMPLATE         |
| parent              | default       | PARENT              |
| type                |               | COUNTER TYPE        |


**Sample:**

```ini
# An example of a PDH Counters section
[/settings/system/windows/counters/sample]
#alias=...
#buffer size=...
#collection strategy=...
#counter=...
#flags=...
#instances=...
is template=false
parent=default
#type=...

```



**Known instances:**

*  disk_queue_length







<a name="/settings/system/windows/real-time/checks"/>
### Legacy generic filters

A set of filters to use in real-time mode


This is a section of objects. This means that you will create objects below this point by adding sections which all look the same.


**Keys:**


| Key           | Default Value             | Description     |
|---------------|---------------------------|-----------------|
| check         | cpu                       | TYPE OF CHECK   |
| command       |                           | COMMAND NAME    |
| critical      |                           | CRITICAL FILTER |
| debug         |                           | DEBUG           |
| destination   |                           | DESTINATION     |
| detail syntax |                           | SYNTAX          |
| empty message | eventlog found no records | EMPTY MESSAGE   |
| escape html   |                           | ESCAPE HTML     |
| filter        |                           | FILTER          |
| maximum age   | 5m                        | MAGIMUM AGE     |
| ok            |                           | OK FILTER       |
| ok syntax     |                           | SYNTAX          |
| perf config   |                           | PERF CONFIG     |
| severity      |                           | SEVERITY        |
| source id     |                           | SOURCE ID       |
| target        |                           | DESTINATION     |
| target id     |                           | TARGET ID       |
| time          |                           | TIME            |
| times         |                           | FILES           |
| top syntax    |                           | SYNTAX          |
| warning       |                           | WARNING FILTER  |


**Sample:**

```ini
# An example of a Legacy generic filters section
[/settings/system/windows/real-time/checks/sample]
check=cpu
#command=...
#critical=...
#debug=...
#destination=...
#detail syntax=...
empty message=eventlog found no records
#escape html=...
#filter=...
maximum age=5m
#ok=...
#ok syntax=...
#perf config=...
#severity=...
#source id=...
#target=...
#target id=...
#time=...
#times=...
#top syntax=...
#warning=...

```






<a name="/settings/system/windows/real-time/cpu"/>
### Realtime cpu filters

A set of filters to use in real-time mode


This is a section of objects. This means that you will create objects below this point by adding sections which all look the same.


**Keys:**


| Key           | Default Value             | Description     |
|---------------|---------------------------|-----------------|
| command       |                           | COMMAND NAME    |
| critical      |                           | CRITICAL FILTER |
| debug         |                           | DEBUG           |
| destination   |                           | DESTINATION     |
| detail syntax |                           | SYNTAX          |
| empty message | eventlog found no records | EMPTY MESSAGE   |
| escape html   |                           | ESCAPE HTML     |
| filter        |                           | FILTER          |
| maximum age   | 5m                        | MAGIMUM AGE     |
| ok            |                           | OK FILTER       |
| ok syntax     |                           | SYNTAX          |
| perf config   |                           | PERF CONFIG     |
| severity      |                           | SEVERITY        |
| source id     |                           | SOURCE ID       |
| target        |                           | DESTINATION     |
| target id     |                           | TARGET ID       |
| time          |                           | TIME            |
| top syntax    |                           | SYNTAX          |
| warning       |                           | WARNING FILTER  |


**Sample:**

```ini
# An example of a Realtime cpu filters section
[/settings/system/windows/real-time/cpu/sample]
#command=...
#critical=...
#debug=...
#destination=...
#detail syntax=...
empty message=eventlog found no records
#escape html=...
#filter=...
maximum age=5m
#ok=...
#ok syntax=...
#perf config=...
#severity=...
#source id=...
#target=...
#target id=...
#time=...
#top syntax=...
#warning=...

```






<a name="/settings/system/windows/real-time/memory"/>
### Realtime memory filters

A set of filters to use in real-time mode


This is a section of objects. This means that you will create objects below this point by adding sections which all look the same.


**Keys:**


| Key           | Default Value             | Description     |
|---------------|---------------------------|-----------------|
| command       |                           | COMMAND NAME    |
| critical      |                           | CRITICAL FILTER |
| debug         |                           | DEBUG           |
| destination   |                           | DESTINATION     |
| detail syntax |                           | SYNTAX          |
| empty message | eventlog found no records | EMPTY MESSAGE   |
| escape html   |                           | ESCAPE HTML     |
| filter        |                           | FILTER          |
| maximum age   | 5m                        | MAGIMUM AGE     |
| ok            |                           | OK FILTER       |
| ok syntax     |                           | SYNTAX          |
| perf config   |                           | PERF CONFIG     |
| severity      |                           | SEVERITY        |
| source id     |                           | SOURCE ID       |
| target        |                           | DESTINATION     |
| target id     |                           | TARGET ID       |
| top syntax    |                           | SYNTAX          |
| type          |                           | MEMORY TYPE     |
| warning       |                           | WARNING FILTER  |


**Sample:**

```ini
# An example of a Realtime memory filters section
[/settings/system/windows/real-time/memory/sample]
#command=...
#critical=...
#debug=...
#destination=...
#detail syntax=...
empty message=eventlog found no records
#escape html=...
#filter=...
maximum age=5m
#ok=...
#ok syntax=...
#perf config=...
#severity=...
#source id=...
#target=...
#target id=...
#top syntax=...
#type=...
#warning=...

```






<a name="/settings/system/windows/real-time/process"/>
### Realtime process filters

A set of filters to use in real-time mode


This is a section of objects. This means that you will create objects below this point by adding sections which all look the same.


**Keys:**


| Key           | Default Value             | Description     |
|---------------|---------------------------|-----------------|
| command       |                           | COMMAND NAME    |
| critical      |                           | CRITICAL FILTER |
| debug         |                           | DEBUG           |
| destination   |                           | DESTINATION     |
| detail syntax |                           | SYNTAX          |
| empty message | eventlog found no records | EMPTY MESSAGE   |
| escape html   |                           | ESCAPE HTML     |
| filter        |                           | FILTER          |
| maximum age   | 5m                        | MAGIMUM AGE     |
| ok            |                           | OK FILTER       |
| ok syntax     |                           | SYNTAX          |
| perf config   |                           | PERF CONFIG     |
| process       |                           | PROCESS         |
| severity      |                           | SEVERITY        |
| source id     |                           | SOURCE ID       |
| target        |                           | DESTINATION     |
| target id     |                           | TARGET ID       |
| top syntax    |                           | SYNTAX          |
| warning       |                           | WARNING FILTER  |


**Sample:**

```ini
# An example of a Realtime process filters section
[/settings/system/windows/real-time/process/sample]
#command=...
#critical=...
#debug=...
#destination=...
#detail syntax=...
empty message=eventlog found no records
#escape html=...
#filter=...
maximum age=5m
#ok=...
#ok syntax=...
#perf config=...
#process=...
#severity=...
#source id=...
#target=...
#target id=...
#top syntax=...
#warning=...

```






